@@ -26,8 +26,8 @@ import (
 	"go.uber.org/zap/zapcore"
 	"moul.io/srand"
 
-	"berty.tech/berty/v2/go/internal/ipfsutil"
-	"berty.tech/berty/v2/go/internal/tinder"
+	"berty.tech/weshnet/pkg/ipfsutil"
+	"berty.tech/weshnet/pkg/tinder"
 )
 
 const timeRounding = time.Microsecond * 10
@@ -164,6 +164,7 @@ func testRDVPs(ctx context.Context, gwg *sync.WaitGroup, addrs []string) {
 							logger.Named("tinder"),
 							host,
 							tgtPi.ID,
+							tinder.PrivateAddrsOnlyFactory,
 							rand.New(rand.NewSource(srand.SafeFast())), //nolint:gosec
 						)
 
