@@ -12,11 +12,12 @@ import (
 	"github.com/rivo/tview"
 	"go.uber.org/zap"
 
-	"berty.tech/berty/v2/go/internal/lifecycle"
 	assets "berty.tech/berty/v2/go/pkg/assets"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/lifecycle"
+	"berty.tech/weshnet/pkg/netmanager"
+	"berty.tech/weshnet/pkg/protocoltypes"
 )
 
 type Opts struct {
@@ -26,6 +27,7 @@ type Opts struct {
 	GroupInvitation  string
 	DisplayName      string
 	LifecycleManager *lifecycle.Manager
+	NetManager       *netmanager.NetManager
 }
 
 var globalLogger *zap.Logger
@@ -46,7 +48,7 @@ func Main(ctx context.Context, opts *Opts) error {
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
 
-	config, err := opts.ProtocolClient.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	config, err := opts.ProtocolClient.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	if err != nil {
 		return errcode.TODO.Wrap(err)
 	}
@@ -66,7 +68,7 @@ func Main(ctx context.Context, opts *Opts) error {
 		globalLogger = zap.NewNop()
 	}
 
-	tabbedView := newTabbedGroups(ctx, accountGroup, opts.ProtocolClient, opts.MessengerClient, app, opts.DisplayName)
+	tabbedView := newTabbedGroups(ctx, accountGroup, opts.ProtocolClient, opts.MessengerClient, app, opts.DisplayName, opts.NetManager)
 	if len(opts.GroupInvitation) > 0 {
 		req := &protocoltypes.GroupMetadataList_Request{GroupPK: accountGroup.Group.PublicKey}
 		cl, err := tabbedView.protocol.GroupMetadataList(ctx, req)
@@ -135,6 +137,8 @@ func Main(ctx context.Context, opts *Opts) error {
 		})
 	*/
 
+	keyboardCommandsMap := buildKeyboardCommandMap()
+
 	app.SetInputCapture(func(event *tcell.EventKey) *tcell.EventKey {
 		/*
 
@@ -146,43 +150,14 @@ func Main(ctx context.Context, opts *Opts) error {
 			inactiveTimer.Reset(ShouldBecomeInactive)
 
 		*/
-
-		// nolint:exhaustive
-		switch event.Key() {
-		case tcell.KeyCtrlC:
-			app.Stop()
-		case tcell.KeyEsc:
-			app.Stop()
-		case tcell.KeyHome:
-			tabbedView.GetActiveViewGroup().messages.historyScroll.ScrollToBeginning()
-		case tcell.KeyEnd:
-			tabbedView.GetActiveViewGroup().messages.historyScroll.ScrollToEnd()
-		case tcell.KeyPgUp:
-			tabbedView.GetActiveViewGroup().ScrollToOffset(-10)
-		case tcell.KeyPgDn:
-			tabbedView.GetActiveViewGroup().ScrollToOffset(+10)
-		case tcell.KeyCtrlP:
-			tabbedView.PrevGroup()
-		case tcell.KeyCtrlN:
-			tabbedView.NextGroup()
-		case tcell.KeyUp:
-			if event.Modifiers() == tcell.ModAlt || event.Modifiers() == tcell.ModCtrl {
-				tabbedView.PrevGroup()
-			} else {
-				input.SetText(tabbedView.GetActiveViewGroup().inputHistory.Prev())
+		if _, ok := keyboardCommandsMap[event.Modifiers()]; ok {
+			if action, ok := keyboardCommandsMap[event.Modifiers()][event.Key()]; ok {
+				action(app, tabbedView, input)
+				return nil
 			}
-
-		case tcell.KeyDown:
-			if event.Modifiers() == tcell.ModAlt || event.Modifiers() == tcell.ModCtrl {
-				tabbedView.NextGroup()
-			} else {
-				input.SetText(tabbedView.GetActiveViewGroup().inputHistory.Next())
-			}
-		default:
-			return event
 		}
 
-		return nil
+		return event
 	})
 
 	if err := app.SetRoot(mainUI, true).SetFocus(mainUI).Run(); err != nil {
