@@ -16,11 +16,10 @@ import (
 	"github.com/rivo/tview"
 	"go.uber.org/zap"
 
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/pkg/banner"
-	"berty.tech/berty/v2/go/pkg/bertyvcissuer"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
 )
 
 type groupView struct {
@@ -33,12 +32,11 @@ type groupView struct {
 	devicePK     []byte
 	acks         sync.Map
 	devices      map[string]*protocoltypes.GroupAddMemberDevice
-	secrets      map[string]*protocoltypes.GroupAddDeviceSecret
+	secrets      map[string]*protocoltypes.GroupAddDeviceChainKey
 	muAggregates sync.Mutex
 	logger       *zap.Logger
 	hasNew       int32
 	lastSentCID  string
-	vcClient     *bertyvcissuer.Client
 }
 
 func (v *groupView) View() tview.Primitive {
@@ -103,7 +101,7 @@ func newViewGroup(v *tabbedGroupsView, g *protocoltypes.Group, memberPK, deviceP
 		inputHistory: newInputHistory(),
 		logger:       logger.With(logutil.PrivateString("group", pkAsShortID(g.PublicKey))),
 		devices:      map[string]*protocoltypes.GroupAddMemberDevice{},
-		secrets:      map[string]*protocoltypes.GroupAddDeviceSecret{},
+		secrets:      map[string]*protocoltypes.GroupAddDeviceChainKey{},
 	}
 }
 
@@ -140,7 +138,7 @@ func (v *groupView) loop(ctx context.Context) {
 	}); err == nil {
 		v.messages.Append(&historyMessage{
 			messageType: messageTypeError,
-			payload:     []byte("conversation opnned " + gpk),
+			payload:     []byte("conversation opened " + gpk),
 		})
 	}
 
@@ -365,7 +363,7 @@ func (v *groupView) welcomeEventDisplay() {
 	v.messages.lock.Unlock()
 	v.messages.Append(&historyMessage{
 		messageType: messageTypeMeta,
-		payload:     []byte("type /help for available commands"),
+		payload:     []byte("type \"/help\" for available commands, \"/keyboard\" for navigation help"),
 	})
 
 	v.welcomeGroupEventDisplay()
