@@ -3,8 +3,6 @@ package mini
 import (
 	"bytes"
 	"context"
-	"crypto/ed25519"
-	crand "crypto/rand"
 	"encoding/base64"
 	"fmt"
 	"io"
@@ -13,17 +11,17 @@ import (
 	"time"
 
 	"github.com/atotto/clipboard"
-	// nolint:staticcheck // cannot use the new protobuf API while keeping gogoproto
-	"github.com/golang/protobuf/proto"
+	"github.com/gdamore/tcell"
+	"github.com/golang/protobuf/proto" // nolint:staticcheck // cannot use the new protobuf API while keeping gogoproto
 	"github.com/ipfs/go-cid"
 	"github.com/mdp/qrterminal/v3"
 	"moul.io/godev"
 
 	"berty.tech/berty/v2/go/pkg/bertylinks"
-	"berty.tech/berty/v2/go/pkg/bertyvcissuer"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/netmanager"
+	"berty.tech/weshnet/pkg/protocoltypes"
 )
 
 type command struct {
@@ -56,6 +54,11 @@ func commandList() []*command {
 			help:  "Displays this message",
 			cmd:   cmdHelp,
 		},
+		{
+			title: "keyboard",
+			help:  "Lists keyboard shortcuts",
+			cmd:   cmdKeyboard,
+		},
 		{
 			title: "group new",
 			help:  "Creates a new group",
@@ -211,6 +214,46 @@ func commandList() []*command {
 			help:  `Completes a credential verification flow`,
 			cmd:   credentialVerificationComplete,
 		},
+		{
+			title: "services credential list",
+			help:  `Lists verified credentials`,
+			cmd:   credentialVerificationList,
+		},
+		{
+			title: "services directory register",
+			help:  `Registers a verified credential on a directory service`,
+			cmd:   directoryServiceRegister,
+		},
+		{
+			title: "services directory unregister",
+			help:  `Unregisters an announced verified credential`,
+			cmd:   directoryServiceUnregister,
+		},
+		{
+			title: "services directory list",
+			help:  `Lists announced verified credential`,
+			cmd:   directoryServiceList,
+		},
+		{
+			title: "services directory query",
+			help:  `Queries a directory service for specified identifiers`,
+			cmd:   directoryServiceQuery,
+		},
+		{
+			title: "dd",
+			help:  `special debug messenger command`,
+			cmd:   newDebugMessengerCommand,
+		},
+		{
+			title: "netmanager get",
+			help:  `Get a netmanager state`,
+			cmd:   newDebugNetManagerGetCommand,
+		},
+		{
+			title: "netmanager set",
+			help:  `Set a netmanager state`,
+			cmd:   newDebugNetManagerSetCommand,
+		},
 		{
 			title:     "/",
 			help:      "",
@@ -220,60 +263,193 @@ func commandList() []*command {
 	}
 }
 
-func credentialVerificationInit(ctx context.Context, v *groupView, service string) error {
-	// TODO: move this to bertyprotocol
-	// FIXME: use a non volatile identity
-	pub, priv, err := ed25519.GenerateKey(crand.Reader)
-	if err != nil {
-		return err
+func directoryServiceRegister(ctx context.Context, v *groupView, cmd string) error {
+	cmdTokens := strings.Split(cmd, " ")
+	if len(cmdTokens) != 2 && len(cmdTokens) != 3 {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected 2 or 3 parameters (server addr, identifier, proof issuer)"))
 	}
 
-	_, webLink, err := bertylinks.MarshalLink(&messengertypes.BertyLink{
-		Kind: messengertypes.BertyLink_ContactInviteV1Kind,
-		BertyID: &messengertypes.BertyID{
-			PublicRendezvousSeed: []byte("testseed"),
-			AccountPK:            pub[:],
-			DisplayName:          "test link",
-		},
+	serverAddr := cmdTokens[0]
+	identifier := cmdTokens[1]
+	proofIssuer := ""
+	if len(cmdTokens) == 3 {
+		proofIssuer = cmdTokens[2]
+	}
+
+	_, err := v.v.messenger.DirectoryServiceRegister(ctx, &messengertypes.DirectoryServiceRegister_Request{
+		Identifier:  identifier,
+		ProofIssuer: proofIssuer,
+		ServerAddr:  serverAddr,
 	})
 	if err != nil {
 		return err
 	}
 
-	v.vcClient = bertyvcissuer.NewClient(service)
-	ctx, cancel := context.WithTimeout(ctx, time.Second*10)
-	defer cancel()
+	return nil
+}
 
-	url, err := v.vcClient.Init(ctx, webLink, priv)
+func directoryServiceUnregister(ctx context.Context, v *groupView, cmd string) error {
+	cmdTokens := strings.Split(cmd, " ")
+	if len(cmdTokens) < 2 {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected 2 or 3 parameters"))
+	}
+
+	serverAddr := cmdTokens[0]
+	directoryRecordToken := cmdTokens[1]
+
+	_, err := v.v.messenger.DirectoryServiceUnregister(ctx, &messengertypes.DirectoryServiceUnregister_Request{
+		ServerAddr:           serverAddr,
+		DirectoryRecordToken: directoryRecordToken,
+	})
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
+
+func directoryServiceList(ctx context.Context, v *groupView, cmd string) error {
+	acc, err := v.v.messenger.AccountGet(ctx, &messengertypes.AccountGet_Request{})
+	if err != nil {
+		return err
+	}
+
+	for _, dsRecord := range acc.Account.DirectoryServiceRecords {
+		revokedPrefix := " "
+		if dsRecord.Revoked {
+			revokedPrefix = "⨯"
+		}
+
+		v.messages.Append(&historyMessage{
+			messageType: messageTypeMeta,
+			payload:     []byte(fmt.Sprintf("%s %s (%s): %s - %d", revokedPrefix, dsRecord.Identifier, dsRecord.DirectoryRecordToken, dsRecord.ServerAddr, dsRecord.ExpirationDate)),
+		})
+	}
+
+	return nil
+}
+
+func directoryServiceQuery(ctx context.Context, v *groupView, cmd string) error {
+	cmdTokens := strings.Split(cmd, " ")
+	if len(cmdTokens) != 2 {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected 2 parameters (server_addr, comma-separated list of identifiers)"))
+	}
+
+	serverAddr := cmdTokens[0]
+	identifiers := strings.Split(cmdTokens[1], ",")
+
+	results, err := v.v.messenger.DirectoryServiceQuery(ctx, &messengertypes.DirectoryServiceQuery_Request{
+		ServerAddr:  serverAddr,
+		Identifiers: identifiers,
+	})
+	if err != nil {
+		return err
+	}
+
+	resultCount := 0
+	for {
+		result, err := results.Recv()
+		if err != nil {
+			break
+		}
+
+		if resultCount == 0 {
+			v.messages.Append(&historyMessage{
+				messageType: messageTypeMeta,
+				payload:     []byte("Query results:"),
+			})
+		}
+
+		resultCount++
+
+		v.messages.Append(&historyMessage{
+			messageType: messageTypeMeta,
+			payload:     []byte(fmt.Sprintf("%d %s: %s", resultCount, result.DirectoryIdentifier, result.AccountURI)),
+		})
+	}
+
+	if resultCount > 0 {
+		v.messages.Append(&historyMessage{
+			messageType: messageTypeMeta,
+			payload:     []byte(strings.Repeat("-", 30)),
+		})
+	} else {
+		v.messages.Append(&historyMessage{
+			messageType: messageTypeMeta,
+			payload:     []byte("No results found"),
+		})
+	}
+
+	return nil
+}
+
+func credentialVerificationInit(ctx context.Context, v *groupView, service string) error {
+	v.v.lock.Lock()
+	displayName := v.v.displayName
+	v.v.lock.Unlock()
+
+	res, err := v.v.messenger.InstanceShareableBertyID(ctx, &messengertypes.InstanceShareableBertyID_Request{
+		DisplayName: displayName,
+	})
+	if err != nil {
+		return err
+	}
+
+	flowDetails, err := v.v.protocol.CredentialVerificationServiceInitFlow(ctx, &protocoltypes.CredentialVerificationServiceInitFlow_Request{
+		ServiceURL: service,
+		PublicKey:  res.Link.BertyID.AccountPK,
+		Link:       res.WebURL,
+	})
 	if err != nil {
 		return err
 	}
 
 	v.messages.Append(&historyMessage{
 		messageType: messageTypeMeta,
-		payload:     []byte(fmt.Sprintf("Auth URL: %s", url)),
+		payload:     []byte(fmt.Sprintf("Auth URL: %s", flowDetails.URL)),
 	})
-	copyToClipboard(v, url)
+	copyToClipboard(v, flowDetails.URL)
 
 	return nil
 }
 
 func credentialVerificationComplete(ctx context.Context, v *groupView, callbackURI string) error {
-	if v.vcClient == nil {
-		return fmt.Errorf("no verification process has been started")
-	}
-
-	_, identifier, err := v.vcClient.Complete(callbackURI)
+	res, err := v.v.protocol.CredentialVerificationServiceCompleteFlow(ctx, &protocoltypes.CredentialVerificationServiceCompleteFlow_Request{
+		CallbackURI: callbackURI,
+	})
 	if err != nil {
 		return err
 	}
 
 	v.messages.Append(&historyMessage{
 		messageType: messageTypeMeta,
-		payload:     []byte(fmt.Sprintf("Completed authentication, associated identifier is <%s>", identifier)),
+		payload:     []byte(fmt.Sprintf("Completed authentication, associated identifier is <%s>", res.Identifier)),
 	})
 
-	v.vcClient = nil
+	return nil
+}
+
+func credentialVerificationList(ctx context.Context, v *groupView, _ string) error {
+	resSrv, err := v.v.protocol.VerifiedCredentialsList(ctx, &protocoltypes.VerifiedCredentialsList_Request{})
+	if err != nil {
+		return err
+	}
+
+	for {
+		cred, err := resSrv.Recv()
+		if err != nil {
+			if err != io.EOF {
+				v.messages.AppendErr(err)
+			}
+
+			break
+		}
+
+		v.messages.Append(&historyMessage{
+			messageType: messageTypeMeta,
+			payload:     []byte(fmt.Sprintf("> <%s> %s", cred.Credential.Identifier, time.Unix(0, cred.Credential.ExpirationDate).String())),
+		})
+	}
 
 	return nil
 }
@@ -400,7 +576,7 @@ func setDisplayName(_ context.Context, v *groupView, cmd string) error {
 }
 
 func debugIPFSCommand(ctx context.Context, v *groupView, _ string) error {
-	config, err := v.v.protocol.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	config, err := v.v.protocol.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	if err != nil {
 		return err
 	}
@@ -541,40 +717,41 @@ func debugInspectStoreCommand(ctx context.Context, v *groupView, cmd string) err
 }
 
 func debugPushCommand(ctx context.Context, v *groupView, _ string) error {
-	if v.lastSentCID == "" {
-		return fmt.Errorf("last message is unknown")
-	}
+	// if v.lastSentCID == "" {
+	// 	return fmt.Errorf("last message is unknown")
+	// }
 
-	c, err := cid.Parse(v.lastSentCID)
-	if err != nil {
-		return err
-	}
+	// c, err := cid.Parse(v.lastSentCID)
+	// if err != nil {
+	// 	return err
+	// }
 
-	res, err := v.v.protocol.PushSend(ctx, &protocoltypes.PushSend_Request{
-		CID:            c.Bytes(),
-		GroupPublicKey: v.g.PublicKey,
-	})
-	if err != nil {
-		return err
-	}
+	// res, err := v.v.protocol.PushSend(ctx, &protocoltypes.PushSend_Request{
+	// 	CID:            c.Bytes(),
+	// 	GroupPublicKey: v.g.PublicKey,
+	// })
+	// if err != nil {
+	// 	return err
+	// }
 
-	if len(res.GroupMembers) == 0 {
-		return fmt.Errorf("no push targets found")
-	}
+	// if len(res.GroupMembers) == 0 {
+	// 	return fmt.Errorf("no push targets found")
+	// }
 
-	targets := []string(nil)
-	for _, m := range res.GroupMembers {
-		for _, d := range m.DevicePKs {
-			targets = append(targets, pkAsShortID(d))
-		}
-	}
+	// targets := []string(nil)
+	// for _, m := range res.GroupMembers {
+	// 	for _, d := range m.DevicePKs {
+	// 		targets = append(targets, pkAsShortID(d))
+	// 	}
+	// }
 
-	v.syncMessages <- &historyMessage{
-		receivedAt: time.Now(),
-		payload:    []byte(fmt.Sprintf("push sent to %s", strings.Join(targets, ", "))),
-	}
+	// v.syncMessages <- &historyMessage{
+	// 	receivedAt: time.Now(),
+	// 	payload:    []byte(fmt.Sprintf("push sent to %s", strings.Join(targets, ", "))),
+	// }
 
-	return nil
+	// FIXME(push):
+	return fmt.Errorf("unimplemented")
 }
 
 func formatDebugInspectGroupStoreReply(rep *protocoltypes.DebugInspectGroupStore_Reply, storeType protocoltypes.DebugInspectGroupLogType) []byte {
@@ -852,6 +1029,54 @@ func cmdHelp(ctx context.Context, v *groupView, cmd string) error {
 	return nil
 }
 
+func cmdKeyboard(ctx context.Context, v *groupView, cmd string) error {
+	longestHint := 0
+	help := [][]string(nil)
+
+	for _, command := range keyboardCommands() {
+		for _, shortcut := range command.shortcuts {
+			eventKey := tcell.NewEventKey(shortcut.key, 0, shortcut.modifier)
+			eventKeyName := eventKey.Name()
+
+			if len(eventKeyName) > longestHint {
+				longestHint = len(eventKeyName)
+			}
+
+			help = append(help, []string{
+				eventKeyName,
+				command.help,
+			})
+		}
+	}
+
+	lastItemCommandHelp := ""
+	sameLabel := "(same)"
+	for _, helpItem := range help {
+		commandHelp := helpItem[1]
+		if commandHelp == lastItemCommandHelp {
+			center := len(commandHelp)/2 - len(sameLabel)/2
+			if center < 0 {
+				center = 0
+			}
+
+			commandHelp = fmt.Sprintf("%s%s", strings.Repeat(" ", center), sameLabel)
+		} else {
+			lastItemCommandHelp = commandHelp
+		}
+
+		v.syncMessages <- &historyMessage{
+			payload: []byte(fmt.Sprintf(
+				"%s%s  %s",
+				helpItem[0],
+				strings.Repeat(" ", longestHint-len(helpItem[0])),
+				commandHelp,
+			)),
+		}
+	}
+
+	return nil
+}
+
 func newSlashMessageCommand(ctx context.Context, v *groupView, cmd string) error {
 	return newMessageCommand(ctx, v, strings.TrimPrefix(cmd, "/"))
 }
@@ -932,6 +1157,10 @@ func contactRequestCommand(ctx context.Context, v *groupView, cmd string) error
 	return err
 }
 
+func newDebugMessengerCommand(ctx context.Context, v *groupView, cmd string) error {
+	return newMessageCommand(ctx, v, fmt.Sprintf("/dd %s", cmd))
+}
+
 func newMessageCommand(ctx context.Context, v *groupView, cmd string) error {
 	if cmd == "" {
 		return nil
@@ -957,6 +1186,83 @@ func newMessageCommand(ctx context.Context, v *groupView, cmd string) error {
 	return nil
 }
 
+func newDebugNetManagerGetCommand(ctx context.Context, v *groupView, cmd string) error {
+	if cmd != "" {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected no argument"))
+	}
+
+	v.syncMessages <- &historyMessage{
+		messageType: messageTypeMeta,
+		payload:     []byte(v.v.netmanager.GetCurrentState().String()),
+	}
+
+	return nil
+}
+
+func newDebugNetManagerSetCommand(ctx context.Context, v *groupView, cmd string) error {
+	if cmd == "" {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected arguments ex: `/netmanager set bluetooth=on nettype=mobile`"))
+	}
+
+	newConnectivityState := v.v.netmanager.GetCurrentState()
+
+	for _, opt := range strings.Split(cmd, " ") {
+		opt = strings.TrimSpace(opt)
+		if opt == "" {
+			continue
+		}
+
+		parts := strings.Split(opt, "=")
+		if len(parts) != 2 {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected a key=value arguments"))
+		}
+
+		switch strings.ToLower(parts[0]) {
+		case "state":
+			state, err := netmanager.ParseConnectivityState(parts[1])
+			if err != nil {
+				return errcode.ErrInvalidInput.Wrap(err)
+			}
+			newConnectivityState.State = state
+		case "metering":
+			metering, err := netmanager.ParseConnectivityState(parts[1])
+			if err != nil {
+				return errcode.ErrInvalidInput.Wrap(err)
+			}
+			newConnectivityState.Metering = metering
+		case "bluetooth":
+			bluetooth, err := netmanager.ParseConnectivityState(parts[1])
+			if err != nil {
+				return errcode.ErrInvalidInput.Wrap(err)
+			}
+			newConnectivityState.Bluetooth = bluetooth
+		case "nettype":
+			nettype, err := netmanager.ParseConnectivityNetType(parts[1])
+			if err != nil {
+				return errcode.ErrInvalidInput.Wrap(err)
+			}
+			newConnectivityState.NetType = nettype
+		case "cellulartype":
+			cellulartype, err := netmanager.ParseConnectivityCellularType(parts[1])
+			if err != nil {
+				return errcode.ErrInvalidInput.Wrap(err)
+			}
+			newConnectivityState.CellularType = cellulartype
+		default:
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("unknown option %q", parts[0]))
+		}
+	}
+
+	v.v.netmanager.UpdateState(newConnectivityState)
+
+	v.syncMessages <- &historyMessage{
+		messageType: messageTypeMeta,
+		payload:     []byte(v.v.netmanager.GetCurrentState().String()),
+	}
+
+	return nil
+}
+
 func contactShareCommand(displayFunc func(*groupView, string)) func(ctx context.Context, v *groupView, cmd string) error {
 	return func(ctx context.Context, v *groupView, cmd string) error {
 		v.v.lock.Lock()
