@@ -16,10 +16,13 @@ import (
 	"berty.tech/berty/v2/go/framework/bertybridge"
 	"berty.tech/berty/v2/go/pkg/accounttypes"
 	bridge_svc "berty.tech/berty/v2/go/pkg/bertybridge"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/protocoltypes"
 )
 
 func Example() {
+	// disable ressources manager for the sake of this example
+	os.Setenv("LIBP2P_RCMGR", "false")
+
 	tmpdir, err := ioutil.TempDir("", "example")
 	checkErr(err)
 	defer os.RemoveAll(tmpdir)
@@ -30,7 +33,6 @@ func Example() {
 		config := bertybridge.NewBridgeConfig()
 		if false { // disabled in example, but not commented to be sure that compiler performs various checks
 			config.SetLifeCycleDriver(nil)
-			config.SetLoggerDriver(nil)
 			config.SetNotificationDriver(nil)
 		}
 
@@ -128,7 +130,7 @@ func Example() {
 
 	// check for GRPC listeners
 	{
-		// create `InstanceGetConfiguration` Input
+		// create `ServiceGetConfiguration` Input
 		input := &accounttypes.GetGRPCListenerAddrs_Request{}
 		payload, err := proto.Marshal(input)
 		checkErr(err)
@@ -174,15 +176,15 @@ func Example() {
 
 	// make unary call to underlying `BertyMessenger` Service
 	{
-		// create `InstanceGetConfiguration` Input
-		input := &protocoltypes.InstanceGetConfiguration_Request{}
+		// create `ServiceGetConfiguration` Input
+		input := &protocoltypes.ServiceGetConfiguration_Request{}
 		payload, err := proto.Marshal(input)
 		checkErr(err)
 
 		// Serialize request
 		in := &bridge_svc.ClientInvokeUnary_Request{
 			MethodDesc: &bridge_svc.MethodDesc{
-				Name: "/berty.protocol.v1.ProtocolService/InstanceGetConfiguration",
+				Name: "/weshnet.protocol.v1.ProtocolService/ServiceGetConfiguration",
 			},
 			Payload: payload,
 		}
@@ -198,7 +200,7 @@ func Example() {
 		err = decodeProtoMessage(ret, &output)
 		checkErr(err)
 
-		var res protocoltypes.InstanceGetConfiguration_Reply
+		var res protocoltypes.ServiceGetConfiguration_Reply
 		err = proto.Unmarshal(output.Payload, &res)
 		checkErr(err)
 
@@ -209,6 +211,7 @@ func Example() {
 	// Output:
 	// [+] initialized.
 	// [+] account created.
+	// go-libp2p resource manager protection disabled
 	// [+] account opened.
 	// [+] has grpc-web listener:            false
 	// [+] has websocket listener:           true
