@@ -17,19 +17,20 @@ import (
 	"google.golang.org/grpc/status"
 
 	"berty.tech/berty/v2/go/internal/grpcutil"
-	"berty.tech/berty/v2/go/internal/ipfsutil"
-	"berty.tech/berty/v2/go/internal/logutil"
-	"berty.tech/berty/v2/go/pkg/authtypes"
-	"berty.tech/berty/v2/go/pkg/bertyauth"
 	"berty.tech/berty/v2/go/pkg/errcode"
+	"berty.tech/weshnet/pkg/authtypes"
+	"berty.tech/weshnet/pkg/bertyauth"
+	"berty.tech/weshnet/pkg/ipfsutil"
+	"berty.tech/weshnet/pkg/logutil"
 )
 
 type GRPCOpts struct {
-	Logger        *zap.Logger
-	AuthPublicKey string
-	AuthSecret    string
-	Listeners     string
-	ServiceID     string
+	Logger                   *zap.Logger
+	AuthPublicKey            string
+	AuthSecret               string
+	Listeners                string
+	ServiceID                string
+	KeepExistingGlobalLogger bool
 }
 
 func InitGRPCServer(workers *run.Group, opts *GRPCOpts) (*grpc.Server, *grpcgw.ServeMux, []grpcutil.Listener, error) {
@@ -55,8 +56,10 @@ func InitGRPCServer(workers *run.Group, opts *GRPCOpts) (*grpc.Server, *grpcgw.S
 
 	zapOpts := []grpc_zap.Option{}
 
-	// override grpc logger
-	logutil.ReplaceGRPCLogger(grpcLogger)
+	if !opts.KeepExistingGlobalLogger {
+		// override grpc logger
+		logutil.ReplaceGRPCLogger(grpcLogger)
+	}
 
 	// noop auth func
 	authFunc := func(ctx context.Context) (context.Context, error) { return ctx, nil }
