@@ -26,27 +26,31 @@ import (
 	"github.com/libp2p/go-libp2p/core/peerstore"
 	p2p_routing "github.com/libp2p/go-libp2p/core/routing"
 	"github.com/libp2p/go-libp2p/p2p/discovery/backoff"
-	"github.com/libp2p/go-libp2p/p2p/host/autorelay"
 	connmgr "github.com/libp2p/go-libp2p/p2p/net/connmgr"
+	quict "github.com/libp2p/go-libp2p/p2p/transport/quic"
+	"github.com/libp2p/go-libp2p/p2p/transport/quicreuse"
 	tcpt "github.com/libp2p/go-libp2p/p2p/transport/tcp"
 	ma "github.com/multiformats/go-multiaddr"
 	manet "github.com/multiformats/go-multiaddr/net"
 	"go.uber.org/zap"
 	"moul.io/srand"
 
-	ble "berty.tech/berty/v2/go/internal/ble-driver"
-	"berty.tech/berty/v2/go/internal/config"
 	"berty.tech/berty/v2/go/internal/datastoreutil"
-	"berty.tech/berty/v2/go/internal/ipfsutil"
-	ipfs_mobile "berty.tech/berty/v2/go/internal/ipfsutil/mobile"
-	"berty.tech/berty/v2/go/internal/logutil"
-	mc "berty.tech/berty/v2/go/internal/multipeer-connectivity-driver"
-	proximity "berty.tech/berty/v2/go/internal/proximitytransport"
-	"berty.tech/berty/v2/go/internal/rendezvous"
-	tinder "berty.tech/berty/v2/go/internal/tinder"
-	"berty.tech/berty/v2/go/pkg/bertyprotocol"
+	"berty.tech/berty/v2/go/internal/encryptedrepo"
+	"berty.tech/berty/v2/go/internal/mdns"
+	"berty.tech/berty/v2/go/pkg/config"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	ipfswebui "berty.tech/ipfs-webui-packed"
+	"berty.tech/weshnet"
+	ble "berty.tech/weshnet/pkg/ble-driver"
+	"berty.tech/weshnet/pkg/ipfsutil"
+	ipfs_mobile "berty.tech/weshnet/pkg/ipfsutil/mobile"
+	"berty.tech/weshnet/pkg/logutil"
+	mc "berty.tech/weshnet/pkg/multipeer-connectivity-driver"
+	"berty.tech/weshnet/pkg/netmanager"
+	proximity "berty.tech/weshnet/pkg/proximitytransport"
+	"berty.tech/weshnet/pkg/rendezvous"
+	tinder "berty.tech/weshnet/pkg/tinder"
 )
 
 // Set the Java Android BLE driver
@@ -64,6 +68,11 @@ func (m *Manager) SetMDNSLocker(mlock sync.Locker) {
 	m.Node.Protocol.MDNS.DriverLocker = mlock
 }
 
+// Set network manager
+func (m *Manager) SetNetManager(netmanager *netmanager.NetManager) {
+	m.Node.Protocol.NetManager = netmanager
+}
+
 const (
 	FlagNameP2PBootstrap                  = "p2p.bootstrap"
 	FlagNameP2PDHT                        = "p2p.dht"
@@ -85,6 +94,10 @@ const (
 	FlagValueP2PDHTAuto       = "auto"
 	FlagValueP2PDHTAutoServer = "autoserver"
 
+	FlagValueP2PDHTNetworkLAN  = "lan"
+	FlagValueP2PDHTNetworkWAN  = "wan"
+	FlagValueP2PDHTNetworkDual = "dual" // both lan & wan
+
 	ipfsIdentityLastUpdateKey = "ipfs_identity_last_update"
 )
 
@@ -99,6 +112,7 @@ func (m *Manager) SetupLocalIPFSFlags(fs *flag.FlagSet) {
 	fs.StringVar(&m.Node.Protocol.Bootstrap, FlagNameP2PBootstrap, KeywordDefault, "ipfs bootstrap node, `:default:` will set ipfs default bootstrap node")
 	fs.StringVar(&m.Node.Protocol.DHT, FlagNameP2PDHT, FlagValueP2PDHTClient, "dht mode, can be: `none`, `client`, `server`, `auto`, `autoserver`")
 	fs.BoolVar(&m.Node.Protocol.DHTRandomWalk, "p2p.dht-randomwalk", true, "if true dht will have randomwalk enable")
+	fs.StringVar(&m.Node.Protocol.DHTNetwork, "p2p.dht-network", FlagValueP2PDHTNetworkDual, "dht network type: lan, wan, dual")
 	fs.StringVar(&m.Node.Protocol.NoAnnounce, "p2p.swarm-no-announce", "", "IPFS exclude announce addrs")
 	fs.BoolVar(&m.Node.Protocol.MDNS.Enable, FlagNameP2PMDNS, true, "if true mdns will be enabled")
 	fs.BoolVar(&m.Node.Protocol.TinderDiscover, FlagNameP2PTinderDiscover, true, "if true enable tinder discovery")
@@ -178,6 +192,19 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 		return nil, nil, errcode.ErrIPFSInit.Wrap(err)
 	}
 
+	var dhtnet ipfsutil.DHTNetworkMode
+	switch m.Node.Protocol.DHTNetwork {
+	case FlagValueP2PDHTNetworkDual:
+		dhtnet = ipfsutil.DHTNetworkDual
+	case FlagValueP2PDHTNetworkLAN:
+		dhtnet = ipfsutil.DHTNetworkLan
+	case FlagValueP2PDHTNetworkWAN:
+		dhtnet = ipfsutil.DHTNetworkWan
+	default:
+		err := fmt.Errorf("invalid dht network")
+		return nil, nil, errcode.ErrIPFSInit.Wrap(err)
+	}
+
 	var routing ipfs_p2p.RoutingOption
 	if dhtmode > 0 && !m.Node.Protocol.DisableIPFSNetwork {
 		dhtopts := []p2p_dht.Option{p2p_dht.Concurrency(1)}
@@ -185,7 +212,7 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 		if !m.Node.Protocol.DHTRandomWalk {
 			dhtopts = append(dhtopts, p2p_dht.DisableAutoRefresh())
 		}
-		routing = ipfsutil.CustomRoutingOption(dhtmode, dhtopts...)
+		routing = ipfsutil.CustomRoutingOption(dhtmode, dhtnet, dhtopts...)
 	} else {
 		routing = ipfs_p2p.NilRouterOption
 	}
@@ -224,26 +251,17 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 		h := mnode.PeerHost()
 		mdnslogger := logger.Named("mdns")
 
-		dh := ipfsutil.DiscoveryHandler(ctx, mdnslogger, h)
-		mdnsService := ipfsutil.NewMdnsService(mdnslogger, h, ipfsutil.MDNSServiceName, dh)
+		dh := mdns.DiscoveryHandler(ctx, mdnslogger, h)
+		m.Node.Protocol.mdnsService = mdns.NewMdnsService(mdnslogger, h, mdns.MDNSServiceName, dh)
 
-		// get multicast interfaces
-		ifaces, err := ipfsutil.GetMulticastInterfaces()
-		if err != nil {
-			return nil, nil, errcode.ErrIPFSInit.Wrap(err)
-		}
-
-		// if multicast interfaces is found, start mdns service
-		if len(ifaces) > 0 {
-			mdnslogger.Info("starting mdns")
-			if err := mdnsService.Start(); err != nil {
-				return nil, nil, errcode.ErrIPFSInit.Wrap(err)
+		go func() {
+			mdnsNetworkManagerConfig := mdns.NetworkManagerConfig{
+				Logger:     logger,
+				NetManager: m.Node.Protocol.NetManager,
+				Service:    m.Node.Protocol.mdnsService,
 			}
-		} else {
-			mdnslogger.Error("unable to start mdns service, no multicast interfaces found")
-		}
-
-		m.Node.Protocol.mdnsService = mdnsService
+			mdns.NetworkManagerHandler(ctx, mdnsNetworkManagerConfig)
+		}()
 	}
 
 	// init extended api
@@ -330,7 +348,7 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 	}
 	// enable lifecycle conn
 	m.Node.Protocol.connlifecycle, err = ipfsutil.NewConnLifecycle(
-		ctx, logger.Named("ipfs-lc"), m.Node.Protocol.ipfsNode.PeerHost, peering, lm,
+		ctx, logger.Named("ipfs-lc"), m.Node.Protocol.ipfsNode.PeerHost, peering, lm, m.Node.Protocol.NetManager,
 	)
 	if err != nil {
 		return nil, nil, errcode.ErrIPFSInit.Wrap(err)
@@ -364,7 +382,7 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 			return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 		}
 
-		ipfsDS := datastoreutil.NewNamespacedDatastore(rootDS, datastore.NewKey(bertyprotocol.NamespaceIPFSDatastore))
+		ipfsDS := datastoreutil.NewNamespacedDatastore(rootDS, datastore.NewKey(weshnet.NamespaceIPFSDatastore))
 
 		repo, err = ipfsutil.CreateMockedRepo(ipfsDS)
 		if err != nil {
@@ -390,7 +408,7 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 	}
 	dbPath := filepath.Join(appDir, "ipfs.sqlite")
 
-	repo, err = ipfsutil.LoadRepoFromPath(dbPath, storageKey, ipfsDatastoreSalt)
+	repo, err = encryptedrepo.LoadEncryptedRepoFromPath(dbPath, storageKey, ipfsDatastoreSalt)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
@@ -431,7 +449,7 @@ func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo
 	}
 
 	if lastUpdate.Before(time.Now().Add(-rendezvousRotationBase)) {
-		repo, err = ipfsutil.ResetExistingRepoIdentity(repo, dbPath, storageKey, ipfsDatastoreSalt)
+		repo, err = encryptedrepo.ResetExistingEncryptedRepoIdentity(repo, dbPath, storageKey, ipfsDatastoreSalt)
 		if err != nil {
 			return nil, errcode.ErrInternal.Wrap(err)
 		}
@@ -477,11 +495,13 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 	}
 
 	// disable original connection manager
-	cfg.Swarm.ConnMgr.Type = "none"
+	cfg.Swarm.ConnMgr.Type = ipfs_cfg.NewOptionalString("none")
 
 	// configure custom conn manager
 	cm, err := connmgr.NewConnManager(
-		cfg.Swarm.ConnMgr.LowWater, cfg.Swarm.ConnMgr.HighWater, connmgr.WithGracePeriod(ipfs_cfg.DefaultConnMgrGracePeriod),
+		int(cfg.Swarm.ConnMgr.LowWater.WithDefault(50)),
+		int(cfg.Swarm.ConnMgr.HighWater.WithDefault(100)),
+		connmgr.WithGracePeriod(ipfs_cfg.DefaultConnMgrGracePeriod),
 	)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupConfig.Wrap(err)
@@ -571,8 +591,8 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 	// enable mdns
 	cfg.Discovery.MDNS.Enabled = false
 
-	// disable managed auto relay
-	cfg.Swarm.RelayClient.Enabled = ipfs_cfg.False
+	// make sure relay is enable
+	cfg.Swarm.RelayClient.Enabled = ipfs_cfg.True
 	cfg.Swarm.Transports.Network.Relay = ipfs_cfg.True
 
 	pis, err := m.getStaticRelays()
@@ -587,10 +607,7 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 			peers[i] = *p
 		}
 
-		p2popts = append(p2popts, libp2p.EnableAutoRelay(
-			autorelay.WithStaticRelays(peers),
-			autorelay.WithCircuitV1Support(),
-		))
+		p2popts = append(p2popts, libp2p.EnableAutoRelayWithStaticRelays(peers))
 	}
 
 	// prefill peerstore with known rdvp servers
@@ -600,8 +617,10 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 	// disable main ipfs pubsub
 	cfg.Pubsub.Enabled = ipfs_cfg.False
 
-	// @NOTE(gfanton): disable quic transport until find a fix on lte
+	// @NOTE(gfanton): disable quic transport so we can init a custom transport
+	// with reusport disable
 	cfg.Swarm.Transports.Network.QUIC = ipfs_cfg.False
+	p2popts = append(p2popts, libp2p.Transport(quict.NewTransport), libp2p.QUICReuse(quicreuse.NewConnManager, quicreuse.DisableReuseport()))
 
 	// @NOTE(gfanton): disable tcp transport so we can init a custom transport
 	// with reusport disable
@@ -657,6 +676,11 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 
 	// rdvp driver
 	if m.Node.Protocol.TinderRDVPDriver {
+		addrsFactory := tinder.PublicAddrsOnlyFactory
+		if m.Node.Protocol.DisableDiscoverFilterAddrs {
+			addrsFactory = tinder.AllAddrsFactory
+		}
+
 		if lenrdvpeers := len(rdvpeers); lenrdvpeers > 0 {
 			for _, peer := range rdvpeers {
 				h.Peerstore().AddAddrs(peer.ID, peer.Addrs, peerstore.PermanentAddrTTL)
@@ -665,7 +689,7 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 				})
 
 				// mqttclient := rendezvous.NewMQTTClient(logger, baseopts)
-				udisc := tinder.NewRendezvousDiscovery(logger, h, peer.ID, rng, m.Node.Protocol.emitterclient)
+				udisc := tinder.NewRendezvousDiscovery(logger, h, peer.ID, addrsFactory, rng, m.Node.Protocol.emitterclient)
 				drivers = append(drivers, udisc)
 			}
 		}
@@ -720,8 +744,8 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 	// 	return errcode.ErrIPFSSetupHost.Wrap(err)
 	// }
 
-	// disc = tinder.NewRotationDiscovery(logger.Named("rotation"), disc, rp)
-	m.Node.Protocol.discAdaptater = tinder.NewDiscoveryAdaptater(logger.Named("disc"), m.Node.Protocol.tinder)
+	m.Node.Protocol.discAdaptater = tinder.NewDiscoveryAdaptater(
+		logger.Named("disc"), m.Node.Protocol.tinder, tinder.FilterOutDrivers(tinder.LocalDiscoveryName))
 	popts = append(popts, pubsub.WithDiscovery(
 		m.Node.Protocol.discAdaptater, pubsub.WithDiscoverConnector(backoffconnector)))
 
@@ -764,7 +788,7 @@ func (m *Manager) getStaticRelays() ([]*peer.AddrInfo, error) {
 	defaultMaddrs := config.Config.P2P.StaticRelays
 
 	var addrs []string
-	for _, v := range strings.Split(m.Node.Protocol.RdvpMaddrs, ",") {
+	for _, v := range strings.Split(m.Node.Protocol.StaticRelays, ",") {
 		switch v {
 		case KeywordDefault:
 			addrs = append(addrs, defaultMaddrs...)
