@@ -9,30 +9,30 @@ import (
 	"strings"
 
 	grpcgw "github.com/grpc-ecosystem/grpc-gateway/runtime"
-	datastore "github.com/ipfs/go-datastore"
 	"go.uber.org/zap"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/credentials/insecure"
 	"gorm.io/gorm"
 
 	"berty.tech/berty/v2/go/internal/accountutils"
-	"berty.tech/berty/v2/go/internal/cryptoutil"
-	"berty.tech/berty/v2/go/internal/datastoreutil"
 	"berty.tech/berty/v2/go/internal/grpcserver"
-	"berty.tech/berty/v2/go/internal/grpcutil"
-	"berty.tech/berty/v2/go/internal/ipfsutil"
-	"berty.tech/berty/v2/go/internal/lifecycle"
-	"berty.tech/berty/v2/go/internal/logutil"
+	berty_grpcutil "berty.tech/berty/v2/go/internal/grpcutil"
 	"berty.tech/berty/v2/go/pkg/bertymessenger"
-	"berty.tech/berty/v2/go/pkg/bertyprotocol"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet"
+	"berty.tech/weshnet/pkg/cryptoutil"
+	"berty.tech/weshnet/pkg/grpcutil"
+	"berty.tech/weshnet/pkg/lifecycle"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/secretstore"
 )
 
 const (
 	FlagNameNodeListeners         = "node.listeners"
 	FlagNameNodeAccountListeners  = "node.account.listeners"
+	FlagNameAllowInsecureService  = "node.service-insecure"
 	FlagValueNodeListeners        = "/ip4/127.0.0.1/tcp/9091/grpc"
 	FlagValueNodeAccountListeners = "/ip4/127.0.0.1/tcp/9092/grpc"
 
@@ -48,7 +48,7 @@ const (
 func (m *Manager) SetupLocalProtocolServerFlags(fs *flag.FlagSet) {
 	m.Node.Protocol.requiredByClient = true
 	fs.StringVar(&m.Node.Protocol.PushPlatformToken, "node.default-push-token", "", "base 64 encoded default platform push token")
-	fs.BoolVar(&m.Node.Protocol.ServiceInsecureMode, "node.service-insecure", false, "use insecure connection on services")
+	fs.BoolVar(&m.Node.ServiceInsecureMode, FlagNameAllowInsecureService, false, "use insecure connection on services")
 	m.SetupDatastoreFlags(fs)
 	m.SetupLocalIPFSFlags(fs)
 	// p2p.remote-ipfs
@@ -130,7 +130,7 @@ func (m *Manager) applyPreset() error {
 	return nil
 }
 
-func (m *Manager) GetLocalProtocolServer() (bertyprotocol.Service, error) {
+func (m *Manager) GetLocalProtocolServer() (weshnet.Service, error) {
 	defer m.prepareForGetter()()
 
 	if m.getContext().Err() != nil {
@@ -153,7 +153,7 @@ func (m *Manager) getPushSecretKey() (*[cryptoutil.KeySize]byte, error) {
 	return pushKey, nil
 }
 
-func (m *Manager) getLocalProtocolServer() (bertyprotocol.Service, error) {
+func (m *Manager) getLocalProtocolServer() (weshnet.Service, error) {
 	if m.Node.Protocol.server != nil {
 		return m.Node.Protocol.server, nil
 	}
@@ -185,31 +185,34 @@ func (m *Manager) getLocalProtocolServer() (bertyprotocol.Service, error) {
 
 	// protocol service
 	{
-		var (
-			deviceDS = ipfsutil.NewDatastoreKeystore(datastoreutil.NewNamespacedDatastore(rootDS, datastore.NewKey(bertyprotocol.NamespaceDeviceKeystore)))
-			deviceKS = cryptoutil.NewDeviceKeystore(deviceDS, nil)
-		)
+		st, err := secretstore.NewSecretStore(rootDS, &secretstore.NewSecretStoreOptions{
+			Logger:               logger.Named("st"),
+			PreComputedKeysCount: 100,
+		})
+		if err != nil {
+			return nil, fmt.Errorf("unable to create new secret store: %w", err)
+		}
 
 		pushKey, err := m.getPushSecretKey()
 		if err != nil {
-			return nil, errcode.TODO.Wrap(err)
+			return nil, fmt.Errorf("unable to get push secret: %w", err)
 		}
 
 		// initialize new protocol client
-		opts := bertyprotocol.Opts{
+		opts := weshnet.Opts{
 			Host:             m.Node.Protocol.ipfsNode.PeerHost,
 			PubSub:           m.Node.Protocol.pubsub,
 			TinderService:    m.Node.Protocol.tinder,
 			IpfsCoreAPI:      m.Node.Protocol.ipfsAPI,
 			Logger:           logger,
 			RootDatastore:    rootDS,
-			DeviceKeystore:   deviceKS,
+			SecretStore:      st,
 			OrbitDB:          odb,
 			PushKey:          pushKey,
-			GRPCInsecureMode: m.Node.Protocol.ServiceInsecureMode,
+			GRPCInsecureMode: m.Node.ServiceInsecureMode,
 		}
 
-		m.Node.Protocol.server, err = bertyprotocol.New(opts)
+		m.Node.Protocol.server, err = weshnet.NewService(opts)
 		if err != nil {
 			return nil, errcode.TODO.Wrap(err)
 		}
@@ -275,8 +278,8 @@ func (m *Manager) getGRPCClientConn() (*grpc.ClientConn, error) {
 		grpcServer := grpc.NewServer(serverOpts...)
 
 		// buffer-based client conn
-		bl := grpcutil.NewBufListener(m.getContext(), 256*1024)
-		cc, err := bl.NewClientConn(clientOpts...)
+		bl := grpcutil.NewBufListener(256 * 1024)
+		cc, err := bl.NewClientConn(m.getContext(), clientOpts...)
 		if err != nil {
 			return nil, errcode.TODO.Wrap(err)
 		}
@@ -440,7 +443,7 @@ func (m *Manager) getGRPCServer() (*grpc.Server, *grpcgw.ServeMux, error) {
 	return m.Node.GRPC.server, m.Node.GRPC.gatewayMux, nil
 }
 
-func (m *Manager) GetGRPCListeners() []grpcutil.Listener {
+func (m *Manager) GetGRPCListeners() []berty_grpcutil.Listener {
 	m.mutex.Lock()
 	defer m.mutex.Unlock()
 	return m.Node.GRPC.listeners
@@ -492,8 +495,22 @@ func (m *Manager) GetReplicationDB() (*gorm.DB, error) {
 }
 
 func (m *Manager) getReplicationDB() (*gorm.DB, error) {
-	if m.Node.Replication.db != nil {
-		return m.Node.Replication.db, nil
+	return m.getServiceDB(&m.Node.Replication.db, &m.Node.Replication.dbCleanup, accountutils.GetReplicationDBForPath)
+}
+
+func (m *Manager) GetDirectoryServiceDB() (*gorm.DB, error) {
+	defer m.prepareForGetter()()
+
+	return m.getDirectoryServiceDB()
+}
+
+func (m *Manager) getDirectoryServiceDB() (*gorm.DB, error) {
+	return m.getServiceDB(&m.Node.DirectoryService.db, &m.Node.DirectoryService.dbCleanup, accountutils.GetDirectoryServiceDBForPath)
+}
+
+func (m *Manager) getServiceDB(dbPtr **gorm.DB, cleanupPtr *func(), dbOpenerFunc func(dir string, logger *zap.Logger) (*gorm.DB, func(), error)) (*gorm.DB, error) {
+	if *dbPtr != nil {
+		return *dbPtr, nil
 	}
 
 	logger, err := m.getLogger()
@@ -506,12 +523,15 @@ func (m *Manager) getReplicationDB() (*gorm.DB, error) {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
-	m.Node.Replication.db, m.Node.Replication.dbCleanup, err = accountutils.GetReplicationDBForPath(dir, logger)
+	db, dbCleanup, err := dbOpenerFunc(dir, logger)
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
-	return m.Node.Replication.db, nil
+	*cleanupPtr = dbCleanup
+	*dbPtr = db
+
+	return *dbPtr, nil
 }
 
 func (m *Manager) restoreMessengerDataFromExport() error {
@@ -604,8 +624,7 @@ func (m *Manager) getLocalMessengerServer() (messengertypes.MessengerServiceServ
 		return nil, errcode.TODO.Wrap(fmt.Errorf("unable to init local protocol server: %w", err))
 	}
 
-	// protocol client
-	protocolClient, err := bertyprotocol.NewClient(m.getContext(), protocolServer, nil, nil) // FIXME: setup tracing
+	protocolClient, err := weshnet.NewClientFromService(m.getContext(), grpc.NewServer(), protocolServer) // FIXME: setup tracing
 	if err != nil {
 		return nil, errcode.TODO.Wrap(fmt.Errorf("unable to init protocol client: %w", err))
 	}
@@ -638,6 +657,7 @@ func (m *Manager) getLocalMessengerServer() (messengertypes.MessengerServiceServ
 		Ring:                m.Logging.ring,
 		PlatformPushToken:   pushPlatformToken,
 		LogFilePath:         currentLogfilePath,
+		GRPCInsecureMode:    m.Node.ServiceInsecureMode,
 	}
 	messengerServer, err := bertymessenger.New(protocolClient, &opts)
 	if err != nil {
