@@ -14,12 +14,12 @@ import (
 	"gorm.io/gorm/clause"
 	"gorm.io/gorm/logger"
 
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
-	"berty.tech/berty/v2/go/pkg/tyber"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
 )
 
 type DBWrapper struct {
@@ -116,6 +116,8 @@ func getDBModels() []interface{} {
 		&messengertypes.ConversationReplicationInfo{},
 		&messengertypes.MetadataEvent{},
 		&messengertypes.SharedPushToken{},
+		&messengertypes.AccountVerifiedCredential{},
+		&messengertypes.AccountDirectoryServiceRecord{},
 	}
 }
 
@@ -415,7 +417,11 @@ func (d *DBWrapper) UpdateAccount(pk, url, displayName string) (*messengertypes.
 // atomic
 func (d *DBWrapper) GetAccount() (*messengertypes.Account, error) {
 	var accounts []messengertypes.Account
-	if err := d.db.Model(&messengertypes.Account{}).Preload("ServiceTokens").Find(&accounts).Error; err != nil {
+	if err := d.db.Model(&messengertypes.Account{}).
+		Preload("ServiceTokens").
+		Preload("VerifiedCredentials").
+		Preload("DirectoryServiceRecords").
+		Find(&accounts).Error; err != nil {
 		return nil, err
 	}
 	if len(accounts) == 0 {
@@ -833,6 +839,12 @@ func (d *DBWrapper) GetDBInfo() (*messengertypes.SystemInfo_DB, error) {
 	infos.SharedPushTokens, err = d.dbModelRowsCount(messengertypes.SharedPushToken{})
 	errs = multierr.Append(errs, err)
 
+	infos.AccountVerifiedCredentials, err = d.dbModelRowsCount(messengertypes.AccountVerifiedCredential{})
+	errs = multierr.Append(errs, err)
+
+	infos.AccountDirectoryServiceRecord, err = d.dbModelRowsCount(messengertypes.AccountDirectoryServiceRecord{})
+	errs = multierr.Append(errs, err)
+
 	return infos, errs
 }
 
@@ -1576,3 +1588,211 @@ func (d *DBWrapper) GetMuteStatusForConversation(key string) (accountMuted bool,
 
 	return accountMuted, conversationMuted, nil
 }
+
+func (d *DBWrapper) SaveAccountVerifiedCredential(ev *protocoltypes.AccountVerifiedCredentialRegistered) error {
+	if ev.ExpirationDate <= messengerutil.MilliToNanoFactor {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("invalid value for expiration date field"))
+	}
+
+	if ev.RegistrationDate <= messengerutil.MilliToNanoFactor || ev.RegistrationDate > ev.ExpirationDate {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("invalid value for registration date field"))
+	}
+
+	if ev.Identifier == "" {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("invalid value for identifier field"))
+	}
+
+	if ev.Issuer == "" {
+		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("invalid value for issuer field"))
+	}
+
+	acc, err := d.GetAccount()
+	if err != nil {
+		return errcode.ErrBertyAccountDataNotFound.Wrap(err)
+	}
+
+	if err := d.db.Transaction(func(tx *gorm.DB) error {
+		elt := &messengertypes.AccountVerifiedCredential{
+			AccountPK:        acc.PublicKey,
+			Identifier:       ev.Identifier,
+			ExpirationDate:   ev.ExpirationDate / messengerutil.MilliToNanoFactor,
+			RegistrationDate: ev.RegistrationDate / messengerutil.MilliToNanoFactor,
+			Issuer:           ev.Issuer,
+		}
+
+		count := int64(0)
+
+		if err := tx.
+			Model(&messengertypes.AccountVerifiedCredential{}).
+			Where("identifier == ? AND issuer == ? AND expiration_date >= ?", ev.Identifier, ev.Issuer, ev.ExpirationDate/messengerutil.MilliToNanoFactor).
+			Count(&count).
+			Error; err != nil {
+			return err
+		}
+
+		if count > 0 {
+			// Nothing to be done, a record already exists for this verified credential (same one or more recent)
+			return nil
+		}
+
+		if err := tx.
+			Model(&messengertypes.AccountVerifiedCredential{}).
+			Where("identifier == ? AND issuer == ? AND expiration_date < ?", ev.Identifier, ev.Issuer, ev.ExpirationDate/messengerutil.MilliToNanoFactor).
+			Count(&count).
+			Error; err != nil {
+			return err
+		}
+
+		if count > 0 {
+			if err := tx.
+				Delete(&messengertypes.AccountVerifiedCredential{}, "identifier == ? AND issuer == ? AND expiration_date < ?", ev.Identifier, ev.Issuer, ev.ExpirationDate/messengerutil.MilliToNanoFactor).
+				Error; err != nil {
+				return err
+			}
+		}
+		if err := tx.Model(&messengertypes.AccountVerifiedCredential{}).Create(elt).Error; err != nil {
+			return errcode.ErrDBWrite.Wrap(err)
+		}
+
+		return nil
+	}); err != nil {
+		return errcode.ErrDBWrite.Wrap(err)
+	}
+
+	return nil
+}
+
+func (d *DBWrapper) GetVerifiedCredentials(identifier string, issuer string) ([]*messengertypes.AccountVerifiedCredential, error) {
+	now := time.Now()
+
+	result := []*messengertypes.AccountVerifiedCredential(nil)
+	qs := d.db.Model(&messengertypes.AccountVerifiedCredential{})
+	if issuer != "" {
+		qs.Where("issuer = ?", issuer)
+	}
+
+	err := qs.Where("identifier = ? AND expiration_date > ?", identifier, now.Unix()/messengerutil.MilliToNanoFactor).Find(&result).Error
+	if err != nil {
+		return nil, errcode.ErrDBRead.Wrap(err)
+	}
+
+	if len(result) == 0 {
+		return nil, errcode.ErrNotFound.Wrap(fmt.Errorf("no verified credentials found"))
+	}
+
+	return result, nil
+}
+
+func (d *DBWrapper) SaveAccountDirectoryServiceRecord(accountPK string, message *messengertypes.AppMessage_AccountDirectoryServiceRegistered) error {
+	return d.db.Transaction(func(tx *gorm.DB) error {
+		count := int64(0)
+
+		if err := tx.Model(&messengertypes.AccountDirectoryServiceRecord{}).Where(
+			"identifier = ? AND server_addr = ? AND expiration_date >= ?", message.Identifier, message.ServerAddr, message.ExpirationDate/messengerutil.MilliToNanoFactor,
+		).Count(&count).Error; err != nil {
+			return errcode.ErrDBRead.Wrap(err)
+		}
+
+		if count > 0 {
+			return errcode.ErrDBEntryAlreadyExists
+		}
+
+		if err := tx.Delete(&messengertypes.AccountDirectoryServiceRecord{}, "identifier = ? AND server_addr = ? AND expiration_date < ?", message.Identifier, message.ServerAddr, message.ExpirationDate/messengerutil.MilliToNanoFactor).Error; err != nil {
+			return errcode.ErrDBWrite.Wrap(err)
+		}
+
+		if message.DirectoryRecordUnregisterToken == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing DirectoryRecordUnregisterToken"))
+		}
+
+		if accountPK == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing accountPK"))
+		}
+
+		if message.Identifier == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing Identifier"))
+		}
+
+		if message.IdentifierProofIssuer == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing IdentifierProofIssuer"))
+		}
+
+		if message.ServerAddr == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing ServerAddr"))
+		}
+
+		if message.RegistrationDate == 0 {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing RegistrationDate"))
+		}
+
+		if message.ExpirationDate == 0 {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing ExpirationDate"))
+		}
+
+		if message.DirectoryRecordToken == "" {
+			return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing DirectoryRecordToken"))
+		}
+
+		serviceRecord := &messengertypes.AccountDirectoryServiceRecord{
+			AccountPK:                      accountPK,
+			Identifier:                     message.Identifier,
+			IdentifierProofIssuer:          message.IdentifierProofIssuer,
+			ServerAddr:                     message.ServerAddr,
+			RegistrationDate:               message.RegistrationDate / messengerutil.MilliToNanoFactor,
+			ExpirationDate:                 message.ExpirationDate / messengerutil.MilliToNanoFactor,
+			DirectoryRecordToken:           message.DirectoryRecordToken,
+			DirectoryRecordUnregisterToken: message.DirectoryRecordUnregisterToken,
+		}
+
+		q := tx.Create(serviceRecord)
+
+		if err := q.Error; err != nil {
+			return errcode.ErrDBWrite.Wrap(err)
+		}
+
+		return nil
+	})
+}
+
+func (d *DBWrapper) MarkAccountDirectoryServiceRecordAsRevoked(serverAddr string, token string, removalDate int64) error {
+	return d.db.Transaction(func(tx *gorm.DB) error {
+		record := &messengertypes.AccountDirectoryServiceRecord{}
+
+		query := d.db.Model(&messengertypes.AccountDirectoryServiceRecord{}).Where(record, &messengertypes.AccountDirectoryServiceRecord{
+			ServerAddr:           serverAddr,
+			DirectoryRecordToken: token,
+		}, "expiration_date <= ?", removalDate).Update("revoked", true)
+
+		if err := query.Error; err != nil {
+			return errcode.ErrDBRead.Wrap(err)
+		}
+
+		if query.RowsAffected == 0 {
+			return errcode.ErrNotFound
+		} else if query.RowsAffected > 1 {
+			d.log.Warn("expected a single result", zap.Int64("count", query.RowsAffected))
+		}
+
+		return nil
+	})
+}
+
+func (d *DBWrapper) GetAccountDirectoryServiceRecord(serviceAddr string, recordToken string) (*messengertypes.AccountDirectoryServiceRecord, error) {
+	count := int64(0)
+	serviceRecord := &messengertypes.AccountDirectoryServiceRecord{}
+
+	if err := d.db.Model(&messengertypes.AccountDirectoryServiceRecord{}).
+		Find(&serviceRecord, "directory_record_token = ? AND server_addr = ?", recordToken, serviceAddr).
+		Count(&count).
+		Error; err != nil {
+		return nil, errcode.ErrDBRead.Wrap(err)
+	}
+
+	if count == 0 {
+		return nil, errcode.ErrNotFound.Wrap(fmt.Errorf("unable to find directory service record"))
+	} else if count > 1 {
+		d.log.Warn("found more results than expected", zap.Int("count", int(count)))
+	}
+
+	return serviceRecord, nil
+}
