@@ -16,13 +16,14 @@ import (
 	"go.uber.org/zap"
 	"gorm.io/gorm"
 
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	mt "berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
-	"berty.tech/berty/v2/go/pkg/tyber"
+	weshnet_errcode "berty.tech/weshnet/pkg/errcode"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
 )
 
 var ErrNilPayload = errcode.ErrInvalidInput.Wrap(errors.New("nil payload"))
@@ -95,16 +96,19 @@ func (h *EventHandler) bindHandlers() {
 		protocoltypes.EventTypePushDeviceTokenRegistered:              h.pushDeviceTokenRegistered,
 		protocoltypes.EventTypePushDeviceServerRegistered:             h.pushDeviceServerRegistered,
 		protocoltypes.EventTypePushMemberTokenUpdate:                  h.pushMemberTokenUpdate,
+		protocoltypes.EventTypeAccountVerifiedCredentialRegistered:    h.accountVerifiedCredentialRegistered,
 	}
 	h.appMessageHandlers = map[mt.AppMessage_Type]struct {
 		handler        func(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) (*mt.Interaction, bool, error)
 		isVisibleEvent bool
 	}{
-		mt.AppMessage_TypeAcknowledge:     {h.handleAppMessageAcknowledge, false},
-		mt.AppMessage_TypeGroupInvitation: {h.handleAppMessageGroupInvitation, true},
-		mt.AppMessage_TypeUserMessage:     {h.handleAppMessageUserMessage, true},
-		mt.AppMessage_TypeSetUserInfo:     {h.handleAppMessageSetUserInfo, false},
-		mt.AppMessage_TypeSetGroupInfo:    {h.handleAppMessageSetGroupInfo, false},
+		mt.AppMessage_TypeAcknowledge:                         {h.handleAppMessageAcknowledge, false},
+		mt.AppMessage_TypeGroupInvitation:                     {h.handleAppMessageGroupInvitation, true},
+		mt.AppMessage_TypeUserMessage:                         {h.handleAppMessageUserMessage, true},
+		mt.AppMessage_TypeSetUserInfo:                         {h.handleAppMessageSetUserInfo, false},
+		mt.AppMessage_TypeSetGroupInfo:                        {h.handleAppMessageSetGroupInfo, false},
+		mt.AppMessage_TypeAccountDirectoryServiceRegistered:   {h.handleAppMessageAccountDirectoryServiceRegistered, false},
+		mt.AppMessage_TypeAccountDirectoryServiceUnregistered: {h.handleAppMessageDirectoryServiceUnregistered, false},
 	}
 }
 
@@ -438,7 +442,7 @@ func (h *EventHandler) accountContactRequestOutgoingSent(gme *protocoltypes.Grou
 	// Check if the event is emitted by the current user
 	ownMemberPK, ownDevicePK, err := h.metaFetcher.OwnMemberAndDevicePKForConversation(h.ctx, gme.EventContext.GroupPK)
 	if err != nil {
-		return errcode.ErrGroupInfo.Wrap(err)
+		return weshnet_errcode.ErrGroupInfo.Wrap(err)
 	}
 
 	var contact *mt.Contact
@@ -512,7 +516,7 @@ func (h *EventHandler) accountContactRequestIncomingReceived(gme *protocoltypes.
 	// Check if the event is emitted by the current user
 	ownMemberPK, ownDevicePK, err := h.metaFetcher.OwnMemberAndDevicePKForConversation(h.ctx, gme.EventContext.GroupPK)
 	if err != nil {
-		return errcode.ErrGroupInfo.Wrap(err)
+		return weshnet_errcode.ErrGroupInfo.Wrap(err)
 	}
 
 	// create new contact conversation
@@ -661,7 +665,7 @@ func (h *EventHandler) multiMemberGroupInitialMemberAnnounced(gme *protocoltypes
 		if err == gorm.ErrRecordNotFound {
 			ownMemberPK, _, err := h.metaFetcher.OwnMemberAndDevicePKForConversation(h.ctx, gpkb)
 			if err != nil {
-				return errcode.ErrGroupInfo.Wrap(err)
+				return weshnet_errcode.ErrGroupInfo.Wrap(err)
 			}
 
 			isMe := bytes.Equal(ownMemberPK, mpkb)
@@ -721,7 +725,7 @@ func (h *EventHandler) groupMemberDeviceAdded(gme *protocoltypes.GroupMetadataEv
 	// Check if the event is emitted by the current user
 	ownMemberPK, _, err := h.metaFetcher.OwnMemberAndDevicePKForConversation(h.ctx, gme.EventContext.GroupPK)
 	if err != nil {
-		return errcode.ErrGroupInfo.Wrap(err)
+		return weshnet_errcode.ErrGroupInfo.Wrap(err)
 	}
 
 	isMe := bytes.Equal(ownMemberPK, mpkb)
@@ -1223,6 +1227,68 @@ func (h *EventHandler) handleAppMessageSetGroupInfo(tx *messengerdb.DBWrapper, i
 	return nil, false, errcode.ErrInternal
 }
 
+func (h *EventHandler) handleAppMessageAccountDirectoryServiceRegistered(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) (*mt.Interaction, bool, error) {
+	if len(i.GetPayload()) == 0 {
+		return nil, false, ErrNilPayload
+	}
+
+	acc, err := tx.GetAccount()
+	if err != nil {
+		return nil, false, err
+	}
+
+	payload := amPayload.(*mt.AppMessage_AccountDirectoryServiceRegistered)
+	if acc.PublicKey != i.ConversationPublicKey {
+		return nil, false, errcode.ErrInvalidInput.Wrap(fmt.Errorf("message is not on account group"))
+	}
+
+	if err := tx.SaveAccountDirectoryServiceRecord(acc.PublicKey, payload); err != nil {
+		return nil, false, err
+	}
+
+	acc, err = tx.GetAccount()
+	if err != nil {
+		return nil, false, err
+	}
+
+	if err := h.dispatcher.StreamEvent(mt.StreamEvent_TypeAccountUpdated, &mt.StreamEvent_AccountUpdated{Account: acc}, false); err != nil {
+		return nil, false, err
+	}
+
+	return i, false, nil
+}
+
+func (h *EventHandler) handleAppMessageDirectoryServiceUnregistered(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) (*mt.Interaction, bool, error) {
+	if len(i.GetPayload()) == 0 {
+		return nil, false, ErrNilPayload
+	}
+
+	acc, err := tx.GetAccount()
+	if err != nil {
+		return nil, false, err
+	}
+
+	payload := amPayload.(*mt.AppMessage_AccountDirectoryServiceUnregistered)
+	if acc.PublicKey != i.ConversationPublicKey {
+		return nil, false, errcode.ErrInvalidInput.Wrap(fmt.Errorf("message is not on account group"))
+	}
+
+	if err := tx.MarkAccountDirectoryServiceRecordAsRevoked(payload.ServerAddr, payload.DirectoryRecordToken, payload.RemovalDate); err != nil {
+		return nil, false, err
+	}
+
+	acc, err = tx.GetAccount()
+	if err != nil {
+		return nil, false, err
+	}
+
+	if err := h.dispatcher.StreamEvent(mt.StreamEvent_TypeAccountUpdated, &mt.StreamEvent_AccountUpdated{Account: acc}, false); err != nil {
+		return nil, false, err
+	}
+
+	return i, false, nil
+}
+
 func interactionFromOutOfStoreAppMessage(h *EventHandler, gPKBytes []byte, outOfStoreMessage *protocoltypes.OutOfStoreMessage, am *mt.AppMessage) (*mt.Interaction, error) {
 	amt := am.GetType()
 	_, c, err := ipfscid.CidFromBytes(outOfStoreMessage.CID)
@@ -1328,6 +1394,29 @@ func (h *EventHandler) pushMemberTokenUpdate(gme *protocoltypes.GroupMetadataEve
 	return nil
 }
 
+func (h *EventHandler) accountVerifiedCredentialRegistered(gme *protocoltypes.GroupMetadataEvent) error {
+	var ev protocoltypes.AccountVerifiedCredentialRegistered
+	if err := proto.Unmarshal(gme.GetEvent(), &ev); err != nil {
+		return err
+	}
+
+	err := h.db.SaveAccountVerifiedCredential(&ev)
+	if err != nil {
+		return errcode.ErrDBWrite.Wrap(err)
+	}
+
+	acc, err := h.db.GetAccount()
+	if err != nil {
+		return errcode.ErrBertyAccountDataNotFound.Wrap(err)
+	}
+
+	if err := h.dispatcher.StreamEvent(mt.StreamEvent_TypeAccountUpdated, &mt.StreamEvent_AccountUpdated{Account: acc}, false); err != nil {
+		return errcode.ErrStreamWrite.Wrap(err)
+	}
+
+	return nil
+}
+
 func (h *EventHandler) pushDeviceServerRegistered(gme *protocoltypes.GroupMetadataEvent) error {
 	var ev protocoltypes.PushDeviceServerRegistered
 	if err := proto.Unmarshal(gme.GetEvent(), &ev); err != nil {
