@@ -19,13 +19,13 @@ import (
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
 
-	"berty.tech/berty/v2/go/internal/grpcutil"
-	"berty.tech/berty/v2/go/internal/testutil"
 	"berty.tech/berty/v2/go/pkg/accounttypes"
 	"berty.tech/berty/v2/go/pkg/bertyaccount"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/grpcutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/testutil"
 )
 
 func TestFlow(t *testing.T) {
@@ -332,7 +332,7 @@ func TestFlow(t *testing.T) {
 		require.Equal(t, lastProgress.Doing, "")
 		require.Equal(t, lastProgress.State, "done")
 		require.True(t, lastProgress.Completed > 1)
-		require.Equal(t, int(lastProgress.Completed), 17) // this test can be disabled if it breaks, the test just above can be considered as enough
+		require.Equal(t, int(lastProgress.Completed), 18) // this test can be disabled if it breaks, the test just above can be considered as enough
 		require.Equal(t, lastProgress.Completed, lastProgress.Total)
 		require.Equal(t, lastProgress.Progress, float32(1))
 
@@ -669,9 +669,9 @@ func createAccountClient(ctx context.Context, t *testing.T, s accounttypes.Accou
 	srv := grpc.NewServer()
 	accounttypes.RegisterAccountServiceServer(srv, s)
 
-	l := grpcutil.NewBufListener(ctx, 2048)
+	l := grpcutil.NewBufListener(2048)
 
-	cc, err := l.NewClientConn()
+	cc, err := l.NewClientConn(ctx)
 	assert.NoError(t, err)
 
 	cl := accounttypes.NewAccountServiceClient(cc)
