@@ -4,7 +4,7 @@ import (
 	context "context"
 	"time"
 
-	"berty.tech/berty/v2/go/internal/lifecycle"
+	"berty.tech/weshnet/pkg/lifecycle"
 )
 
 func (s *service) handleLifecycle(ctx context.Context) {
