@@ -20,21 +20,19 @@ import (
 	"moul.io/u"
 
 	"berty.tech/berty/v2/go/internal/accountutils"
-	nb "berty.tech/berty/v2/go/internal/androidnearby"
-	"berty.tech/berty/v2/go/internal/ble-driver"
-	"berty.tech/berty/v2/go/internal/config"
 	"berty.tech/berty/v2/go/internal/initutil"
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/migrationsaccount"
-	mc "berty.tech/berty/v2/go/internal/multipeer-connectivity-driver"
-	"berty.tech/berty/v2/go/localization"
 	"berty.tech/berty/v2/go/pkg/accounttypes"
-	"berty.tech/berty/v2/go/pkg/bertypush"
+	"berty.tech/berty/v2/go/pkg/config"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
-	"berty.tech/berty/v2/go/pkg/tyber"
-	"berty.tech/berty/v2/go/pkg/username"
+	nb "berty.tech/weshnet/pkg/androidnearby"
+	"berty.tech/weshnet/pkg/ble-driver"
+	"berty.tech/weshnet/pkg/logutil"
+	mc "berty.tech/weshnet/pkg/multipeer-connectivity-driver"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
+	"berty.tech/weshnet/pkg/username"
 )
 
 func (s *service) openAccount(ctx context.Context, req *accounttypes.OpenAccount_Request, prog *progress.Progress) (*accounttypes.AccountMetadata, error) {
@@ -455,6 +453,7 @@ func (s *service) openManager(kind string, defaultLoggerStreams []logutil.Stream
 	manager.SetBleDriver(s.bleDriver)
 	manager.SetNBDriver(s.nbDriver)
 	manager.SetMDNSLocker(s.mdnslocker)
+	manager.SetNetManager(s.netmanager)
 	manager.SetLifecycleManager(s.lifecycleManager)
 
 	return manager, nil
@@ -957,29 +956,31 @@ func NetworkConfigGetDefault() *accounttypes.NetworkConfig {
 	}
 
 	return &accounttypes.NetworkConfig{
-		Bootstrap:                  []string{initutil.KeywordDefault},
-		Rendezvous:                 []string{initutil.KeywordDefault},
-		StaticRelay:                []string{initutil.KeywordDefault},
-		DHT:                        accounttypes.NetworkConfig_DHTClient,
-		BluetoothLE:                accounttypes.NetworkConfig_Disabled,
-		AndroidNearby:              accounttypes.NetworkConfig_Disabled,
-		AppleMultipeerConnectivity: accounttypes.NetworkConfig_Disabled,
-		MDNS:                       accounttypes.NetworkConfig_Enabled,
-		Tor:                        accounttypes.NetworkConfig_TorDisabled,
+		Bootstrap:                    []string{initutil.KeywordDefault},
+		Rendezvous:                   []string{initutil.KeywordDefault},
+		StaticRelay:                  []string{initutil.KeywordDefault},
+		DHT:                          accounttypes.NetworkConfig_DHTClient,
+		BluetoothLE:                  accounttypes.NetworkConfig_Disabled,
+		AndroidNearby:                accounttypes.NetworkConfig_Disabled,
+		AppleMultipeerConnectivity:   accounttypes.NetworkConfig_Disabled,
+		MDNS:                         accounttypes.NetworkConfig_Enabled,
+		Tor:                          accounttypes.NetworkConfig_TorDisabled,
+		AllowUnsecureGRPCConnections: accounttypes.NetworkConfig_Disabled,
 	}
 }
 
 func NetworkConfigGetBlank() *accounttypes.NetworkConfig {
 	return &accounttypes.NetworkConfig{
-		Bootstrap:                  []string{initutil.KeywordDefault},
-		Rendezvous:                 []string{initutil.KeywordDefault},
-		StaticRelay:                []string{initutil.KeywordDefault},
-		DHT:                        accounttypes.NetworkConfig_DHTUndefined,
-		BluetoothLE:                accounttypes.NetworkConfig_Undefined,
-		AndroidNearby:              accounttypes.NetworkConfig_Undefined,
-		AppleMultipeerConnectivity: accounttypes.NetworkConfig_Undefined,
-		MDNS:                       accounttypes.NetworkConfig_Undefined,
-		Tor:                        accounttypes.NetworkConfig_TorUndefined,
+		Bootstrap:                    []string{initutil.KeywordDefault},
+		Rendezvous:                   []string{initutil.KeywordDefault},
+		StaticRelay:                  []string{initutil.KeywordDefault},
+		DHT:                          accounttypes.NetworkConfig_DHTUndefined,
+		BluetoothLE:                  accounttypes.NetworkConfig_Undefined,
+		AndroidNearby:                accounttypes.NetworkConfig_Undefined,
+		AppleMultipeerConnectivity:   accounttypes.NetworkConfig_Undefined,
+		MDNS:                         accounttypes.NetworkConfig_Undefined,
+		Tor:                          accounttypes.NetworkConfig_TorUndefined,
+		AllowUnsecureGRPCConnections: accounttypes.NetworkConfig_Undefined,
 	}
 }
 
@@ -1137,6 +1138,7 @@ func AddArgsUsingNetworkConfig(m *accounttypes.NetworkConfig, args []string) []s
 	args = addFlagValueArgs(args, initutil.FlagNameP2PMultipeerConnectivity, mc.Supported, defaultConfig.AppleMultipeerConnectivity, m.AppleMultipeerConnectivity)
 	args = addFlagValueArgs(args, initutil.FlagNameP2PNearby, nb.Supported, defaultConfig.AndroidNearby, m.AndroidNearby)
 	args = addFlagValueArgs(args, initutil.FlagNameP2PMDNS, true, defaultConfig.MDNS, m.MDNS)
+	args = addFlagValueArgs(args, initutil.FlagNameAllowInsecureService, true, defaultConfig.AllowUnsecureGRPCConnections, m.AllowUnsecureGRPCConnections)
 
 	args = AddDHTArgsUsingNetworkConfig(m, args, defaultConfig)
 	args = AddRDVPArgsUsingNetworkConfig(m, args, defaultConfig)
@@ -1255,104 +1257,109 @@ func ArgsHasWithPrefix(args []string, prefix string) bool {
 }
 
 func (s *service) PushReceive(ctx context.Context, req *accounttypes.PushReceive_Request) (*accounttypes.PushReceive_Reply, error) {
-	payload, err := base64.RawURLEncoding.DecodeString(req.Payload)
-	if err != nil {
-		return nil, errcode.ErrDeserialization.Wrap(err)
-	}
+	// FIXME(push): need re bertypush re implementation
+	return nil, fmt.Errorf("not implemented")
 
-	initManager, err := s.getInitManager()
-	if err != nil {
-		s.logger.Warn("unable to retrieve init manager", zap.Error(err))
-		initManager = nil
-	}
+	// payload, err := base64.RawURLEncoding.DecodeString(req.Payload)
+	// if err != nil {
+	// 	return nil, errcode.ErrDeserialization.Wrap(err)
+	// }
 
-	cat := localization.Catalog()
-	printer := cat.NewPrinter(s.languages...)
+	// initManager, err := s.getInitManager()
+	// if err != nil {
+	// 	s.logger.Warn("unable to retrieve init manager", zap.Error(err))
+	// 	initManager = nil
+	// }
 
-	s.muService.Lock()
-	defer s.muService.Unlock()
+	// cat := localization.Catalog()
+	// printer := cat.NewPrinter(s.languages...)
 
-	excludedAccounts := []string(nil)
+	// s.muService.Lock()
+	// defer s.muService.Unlock()
 
-	accData := s.accountData
-	if initManager != nil && accData != nil {
-		excludedAccounts = append(excludedAccounts, accData.AccountID)
+	// excludedAccounts := []string(nil)
 
-		client, err := initManager.GetMessengerClient()
-		if err == nil && client != nil {
-			rep, err := client.PushReceive(ctx, &messengertypes.PushReceive_Request{Payload: payload})
-			if err == nil {
-				pushData, err := bertypush.PushEnrich(rep.Data, accData, s.logger)
-				formated := bertypush.FormatDecryptedPush(pushData, printer)
-				if err == nil {
-					return &accounttypes.PushReceive_Reply{
-						PushData: pushData,
-						Push:     formated,
-					}, nil
-				}
+	// accData := s.accountData
+	// if initManager != nil && accData != nil {
+	// 	excludedAccounts = append(excludedAccounts, accData.AccountID)
 
-				s.logger.Warn("unable to enrich push data", zap.Error(err))
-				// TODO: should we return early?
-			}
+	// 	client, err := initManager.GetMessengerClient()
+	// 	if err == nil && client != nil {
+	// 		rep, err := client.PushReceive(ctx, &messengertypes.PushReceive_Request{Payload: payload})
+	// 		if err == nil {
+	// 			pushData, err := bertypush.PushEnrich(rep.Data, accData, s.logger)
+	// 			formated := bertypush.FormatDecryptedPush(pushData, printer)
+	// 			if err == nil {
+	// 				return &accounttypes.PushReceive_Reply{
+	// 					PushData: pushData,
+	// 					Push:     formated,
+	// 				}, nil
+	// 			}
 
-			s.logger.Warn("unable to open push using currently opened account", zap.Error(err))
-		} else if err != nil {
-			s.logger.Warn("unable to get currently opened account", zap.Error(err))
-		}
-	}
+	// 			s.logger.Warn("unable to enrich push data", zap.Error(err))
+	// 			// TODO: should we return early?
+	// 		}
 
-	rawPushData, accountData, err := bertypush.PushDecrypt(ctx, s.sharedRootDir, payload, &bertypush.PushDecryptOpts{
-		Logger: s.logger, ExcludedAccounts: excludedAccounts, Keystore: s.nativeKeystore,
-	})
-	if err != nil {
-		return nil, errcode.ErrPushUnableToDecrypt.Wrap(err)
-	}
+	// 		s.logger.Warn("unable to open push using currently opened account", zap.Error(err))
+	// 	} else if err != nil {
+	// 		s.logger.Warn("unable to get currently opened account", zap.Error(err))
+	// 	}
+	// }
 
-	pushData, err := bertypush.PushEnrich(rawPushData, accountData, s.logger)
-	if err != nil {
-		s.logger.Warn("unable to enrich push data", zap.Error(err))
-		// TODO: should we return early?
-	}
+	// rawPushData, accountData, err := bertypush.PushDecrypt(ctx, s.sharedRootDir, payload, &bertypush.PushDecryptOpts{
+	// 	Logger: s.logger, ExcludedAccounts: excludedAccounts, Keystore: s.nativeKeystore,
+	// })
+	// if err != nil {
+	// 	return nil, weshnet_errcode.ErrPushUnableToDecrypt.Wrap(err)
+	// }
 
-	formated := bertypush.FormatDecryptedPush(pushData, printer)
-	return &accounttypes.PushReceive_Reply{
-		PushData: pushData,
-		Push:     formated,
-	}, nil
+	// pushData, err := bertypush.PushEnrich(rawPushData, accountData, s.logger)
+	// if err != nil {
+	// 	s.logger.Warn("unable to enrich push data", zap.Error(err))
+	// 	// TODO: should we return early?
+	// }
+
+	// formated := bertypush.FormatDecryptedPush(pushData, printer)
+	// return &accounttypes.PushReceive_Reply{
+	// 	PushData: pushData,
+	// 	Push:     formated,
+	// }, nil
 }
 
 func (s *service) PushPlatformTokenRegister(ctx context.Context, request *accounttypes.PushPlatformTokenRegister_Request) (*accounttypes.PushPlatformTokenRegister_Reply, error) {
 	s.muService.Lock()
 	defer s.muService.Unlock()
 
-	pushPK, _, err := accountutils.GetDevicePushKeyForPath(s.devicePushKeyPath, true)
-	if err != nil {
-		return nil, err
-	}
+	// FIXME(push): method unavailable, missing `PushSetDeviceToken` method
 
-	request.Receiver.RecipientPublicKey = pushPK[:]
+	// pushPK, _, err := accountutils.GetDevicePushKeyForPath(s.devicePushKeyPath, true)
+	// if err != nil {
+	// 	return nil, err
+	// }
 
-	s.pushPlatformToken = &protocoltypes.PushServiceReceiver{
-		TokenType:          request.Receiver.TokenType,
-		BundleID:           request.Receiver.BundleID,
-		Token:              request.Receiver.Token,
-		RecipientPublicKey: request.Receiver.RecipientPublicKey,
-	}
+	// request.Receiver.RecipientPublicKey = pushPK[:]
 
-	if s.initManager == nil {
-		return &accounttypes.PushPlatformTokenRegister_Reply{}, nil
-	}
+	// s.pushPlatformToken = &protocoltypes.PushServiceReceiver{
+	// 	TokenType:          request.Receiver.TokenType,
+	// 	BundleID:           request.Receiver.BundleID,
+	// 	Token:              request.Receiver.Token,
+	// 	RecipientPublicKey: request.Receiver.RecipientPublicKey,
+	// }
 
-	client, err := s.initManager.GetProtocolClient()
-	if err != nil {
-		return nil, errcode.ErrInternal.Wrap(err)
-	}
+	// if s.initManager == nil {
+	// 	return &accounttypes.PushPlatformTokenRegister_Reply{}, nil
+	// }
 
-	if _, err := client.PushSetDeviceToken(ctx, &protocoltypes.PushSetDeviceToken_Request{Receiver: request.Receiver}); err != nil {
-		return nil, errcode.ErrInternal.Wrap(err)
-	}
+	// client, err := s.initManager.GetProtocolClient()
+	// if err != nil {
+	// 	return nil, errcode.ErrInternal.Wrap(err)
+	// }
 
-	return &accounttypes.PushPlatformTokenRegister_Reply{}, nil
+	// if _, err := client.PushSetDeviceToken(ctx, &protocoltypes.PushSetDeviceToken_Request{Receiver: request.Receiver}); err != nil {
+	// 	return nil, errcode.ErrInternal.Wrap(err)
+	// }
+
+	return nil, fmt.Errorf("not implemented")
 }
 
 func (s *service) GetOpenedAccount(ctx context.Context, request *accounttypes.GetOpenedAccount_Request) (*accounttypes.GetOpenedAccount_Reply, error) {
