@@ -3,9 +3,9 @@ package bertymessenger
 import (
 	"bufio"
 	"context"
+	"crypto/tls"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"math"
 	mrand "math/rand"
 	"net"
@@ -20,23 +20,27 @@ import (
 	backoff "github.com/libp2p/go-libp2p/p2p/discovery/backoff"
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
+	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
+	"google.golang.org/grpc/credentials"
+	"google.golang.org/grpc/credentials/insecure"
 	"google.golang.org/grpc/status"
 	"moul.io/srand"
 
 	"berty.tech/berty/v2/go/internal/discordlog"
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/internal/sysutil"
-	"berty.tech/berty/v2/go/pkg/authtypes"
 	"berty.tech/berty/v2/go/pkg/banner"
 	"berty.tech/berty/v2/go/pkg/bertylinks"
+	"berty.tech/berty/v2/go/pkg/directorytypes"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
 	"berty.tech/berty/v2/go/pkg/tempdir"
-	"berty.tech/berty/v2/go/pkg/tyber"
+	"berty.tech/weshnet/pkg/authtypes"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
 )
 
 func (svc *service) DevShareInstanceBertyID(ctx context.Context, req *messengertypes.DevShareInstanceBertyID_Request) (*messengertypes.DevShareInstanceBertyID_Reply, error) {
@@ -98,7 +102,7 @@ func (svc *service) internalInstanceShareableBertyID(ctx context.Context, req *m
 	if req == nil {
 		req = &messengertypes.InstanceShareableBertyID_Request{}
 	}
-	config, err := svc.protocolClient.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	config, err := svc.protocolClient.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -915,6 +919,25 @@ func (svc *service) Interact(ctx context.Context, req *messengertypes.Interact_R
 	gpk := req.GetConversationPublicKey()
 	payloadType := req.GetType()
 
+	// check for debug command
+	switch payloadType {
+	case messengertypes.AppMessage_TypeUserMessage:
+		var m messengertypes.AppMessage_UserMessage
+		if err := proto.Unmarshal(req.Payload, &m); err != nil {
+			return nil, errcode.ErrInvalidInput.Wrap(err)
+		}
+
+		// handle debug input
+		const debugcmd = "/dd"
+		if strings.HasPrefix(m.Body, debugcmd) {
+			svc.logger.Debug("[DD] handling command", zap.String("cmd", m.Body))
+			return &messengertypes.Interact_Reply{}, svc.debug(ctx, req, strings.TrimPrefix(m.Body, debugcmd))
+		}
+
+		// no debug command, ignore and continue
+	default:
+	}
+
 	ctx, newTrace, endSection := tyber.Section(ctx, svc.logger, fmt.Sprintf("Interacting with %s on group %s", strings.TrimPrefix(payloadType.String(), "Type"), gpk))
 	defer func() {
 		if err != nil {
@@ -1271,7 +1294,7 @@ func (svc *service) BannerQuote(ctx context.Context, req *messengertypes.BannerQ
 }
 
 func (svc *service) ReplicationSetAutoEnable(ctx context.Context, req *messengertypes.ReplicationSetAutoEnable_Request) (*messengertypes.ReplicationSetAutoEnable_Reply, error) {
-	config, err := svc.protocolClient.InstanceGetConfiguration(svc.ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	config, err := svc.protocolClient.ServiceGetConfiguration(svc.ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	if err != nil {
 		return nil, err
 	}
@@ -1294,14 +1317,14 @@ func (svc *service) ReplicationSetAutoEnable(ctx context.Context, req *messenger
 }
 
 func (svc *service) InstanceExportData(_ *messengertypes.InstanceExportData_Request, server messengertypes.MessengerService_InstanceExportDataServer) error {
-	tmpFile, err := ioutil.TempFile(tempdir.TempDir(), "export-")
+	tmpFile, err := os.CreateTemp(tempdir.TempDir(), "export-")
 	if err != nil {
 		return errcode.ErrInternal.Wrap(err)
 	}
 
 	defer os.Remove(tmpFile.Name())
 
-	cl, err := svc.protocolClient.InstanceExportData(server.Context(), &protocoltypes.InstanceExportData_Request{})
+	cl, err := svc.protocolClient.ServiceExportData(server.Context(), &protocoltypes.ServiceExportData_Request{})
 	if err != nil {
 		return errcode.ErrInternal.Wrap(err)
 	}
@@ -1620,7 +1643,7 @@ func (svc *service) TyberHostAttach(ctx context.Context, request *messengertypes
 }
 
 func (svc *service) PushSetAutoShare(ctx context.Context, request *messengertypes.PushSetAutoShare_Request) (*messengertypes.PushSetAutoShare_Reply, error) {
-	config, err := svc.protocolClient.InstanceGetConfiguration(svc.ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	config, err := svc.protocolClient.ServiceGetConfiguration(svc.ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	if err != nil {
 		return nil, err
 	}
@@ -1653,7 +1676,7 @@ func (svc *service) PushSetAutoShare(ctx context.Context, request *messengertype
 	return &messengertypes.PushSetAutoShare_Reply{}, nil
 }
 
-func (svc *service) interactionDelayedActions(id ipfscid.Cid, groupPK []byte) {
+func (svc *service) interactionDelayedActions(id ipfscid.Cid, _ []byte) {
 	// TODO: decouple action from this method
 
 	if !id.Defined() {
@@ -1669,24 +1692,27 @@ func (svc *service) interactionDelayedActions(id ipfscid.Cid, groupPK []byte) {
 	// svc.handlerMutex.Lock()
 	// defer svc.handlerMutex.Unlock()
 
-	svc.logger.Info("attempting to push interaction", logutil.PrivateString("cid", id.String()))
-	_, err := svc.protocolClient.PushSend(svc.ctx, &protocoltypes.PushSend_Request{
-		CID:            id.Bytes(),
-		GroupPublicKey: groupPK,
-	})
-	if err != nil {
-		svc.logger.Error("unable to push interaction", zap.Error(err), logutil.PrivateString("cid", id.String()))
-		return
-	}
+	// FIXME(push): fix push send interaction
+	svc.logger.Info("push send not available", logutil.PrivateString("cid", id.String()))
+	// svc.logger.Info("attempting to push interaction", logutil.PrivateString("cid", id.String()))
+	// _, err := svc.protocolClient.PushSend(svc.ctx, &protocoltypes.PushSend_Request{
+	// 	CID:            id.Bytes(),
+	// 	GroupPublicKey: groupPK,
+	// })
+	// if err != nil {
+	// 	svc.logger.Error("unable to push interaction", zap.Error(err), logutil.PrivateString("cid", id.String()))
+	// 	return
+	// }
 
-	svc.logger.Info("pushed interaction", logutil.PrivateString("cid", id.String()))
+	// svc.logger.Info("pushed interaction", logutil.PrivateString("cid", id.String()))
 }
 
 func (svc *service) PushReceive(ctx context.Context, request *messengertypes.PushReceive_Request) (*messengertypes.PushReceive_Reply, error) {
 	svc.handlerMutex.Lock()
 	defer svc.handlerMutex.Unlock()
 
-	return svc.pushReceiver.PushReceive(ctx, request.Payload)
+	// FIXME(push) pushreceive not implemented
+	return nil, fmt.Errorf("not implemented")
 }
 
 func (svc *service) ListMemberDevices(request *messengertypes.ListMemberDevices_Request, server messengertypes.MessengerService_ListMemberDevicesServer) error {
@@ -1731,3 +1757,195 @@ func (svc *service) PushTokenSharedForConversation(request *messengertypes.PushT
 
 	return nil
 }
+
+func (svc *service) getDirectoryServiceClient(ctx context.Context, serverAddr string) (directorytypes.DirectoryServiceClient, error) {
+	gopts := []grpc.DialOption(nil)
+
+	if svc.grpcInsecure {
+		gopts = append(gopts, grpc.WithTransportCredentials(insecure.NewCredentials()))
+	} else {
+		tlsconfig := credentials.NewTLS(&tls.Config{
+			MinVersion: tls.VersionTLS12,
+		})
+		gopts = append(gopts, grpc.WithTransportCredentials(tlsconfig))
+	}
+
+	cc, err := grpc.DialContext(ctx, serverAddr, gopts...)
+	if err != nil {
+		return nil, errcode.ErrStreamWrite.Wrap(err)
+	}
+
+	return directorytypes.NewDirectoryServiceClient(cc), nil
+}
+
+func (svc *service) getVerifiedCredentialFromProtocol(ctx context.Context, identifier, issuer string) (*protocoltypes.AccountVerifiedCredentialRegistered, error) {
+	subCtx, cancel := context.WithCancel(ctx)
+	defer cancel()
+
+	vcs, err := svc.db.GetVerifiedCredentials(identifier, issuer)
+	if err != nil {
+		return nil, errcode.ErrInvalidInput.Wrap(err)
+	}
+
+	srv, err := svc.protocolClient.VerifiedCredentialsList(subCtx, &protocoltypes.VerifiedCredentialsList_Request{
+		FilterIssuer:     vcs[0].Issuer,
+		FilterIdentifier: vcs[0].Identifier,
+		ExcludeExpired:   true,
+	})
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	// Taking only the first result
+	srvVC, err := srv.Recv()
+	if err != nil {
+		if err == io.EOF {
+			return nil, errcode.ErrNotFound
+		}
+
+		return nil, errcode.ErrStreamRead.Wrap(err)
+	}
+
+	return srvVC.Credential, nil
+}
+
+func (svc *service) DirectoryServiceRegister(ctx context.Context, request *messengertypes.DirectoryServiceRegister_Request) (*messengertypes.DirectoryServiceRegister_Reply, error) {
+	selectedRegisteredVC, err := svc.getVerifiedCredentialFromProtocol(ctx, request.Identifier, request.ProofIssuer)
+	if err != nil {
+		return nil, errcode.ErrNotFound.Wrap(err)
+	}
+
+	client, err := svc.getDirectoryServiceClient(ctx, request.ServerAddr)
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	acc, err := svc.db.GetAccount()
+	if err != nil {
+		svc.logger.Error("AccountUpdate: failed to get account", zap.Error(err))
+		return nil, errcode.TODO.Wrap(err)
+	}
+
+	shareableID, err := svc.internalInstanceShareableBertyID(ctx, &messengertypes.InstanceShareableBertyID_Request{
+		DisplayName: acc.DisplayName,
+	})
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	// TODO: request.ExpirationDate
+	registrationResponse, err := client.Register(ctx, &directorytypes.Register_Request{
+		VerifiedCredential: []byte(selectedRegisteredVC.VerifiedCredential),
+		AccountURI:         shareableID.WebURL,
+	})
+	if err != nil {
+		return nil, errcode.ErrServicesDirectory.Wrap(err)
+	}
+
+	am, err := messengertypes.AppMessage_TypeAccountDirectoryServiceRegistered.MarshalPayload(messengerutil.TimestampMs(time.Now()), "", &messengertypes.AppMessage_AccountDirectoryServiceRegistered{
+		Identifier:                     selectedRegisteredVC.Identifier,
+		IdentifierProofIssuer:          selectedRegisteredVC.Issuer,
+		RegistrationDate:               time.Now().UnixNano(),
+		ExpirationDate:                 registrationResponse.ExpirationDate,
+		ServerAddr:                     request.ServerAddr,
+		DirectoryRecordToken:           registrationResponse.DirectoryRecordToken,
+		DirectoryRecordUnregisterToken: registrationResponse.UnregisterToken,
+	})
+	if err != nil {
+		return nil, errcode.ErrSerialization.Wrap(err)
+	}
+
+	_, err = svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{GroupPK: svc.accountGroup, Payload: am})
+	if err != nil {
+		return nil, errcode.ErrProtocolSend.Wrap(err)
+	}
+
+	return &messengertypes.DirectoryServiceRegister_Reply{
+		DirectoryRecordToken: registrationResponse.DirectoryRecordToken,
+	}, nil
+}
+
+func (svc *service) DirectoryServiceUnregister(ctx context.Context, request *messengertypes.DirectoryServiceUnregister_Request) (*messengertypes.DirectoryServiceUnregister_Reply, error) {
+	if request.DirectoryRecordToken == "" {
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing directory_record_token"))
+	}
+
+	if request.ServerAddr == "" {
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing server_addr"))
+	}
+
+	record, err := svc.db.GetAccountDirectoryServiceRecord(request.ServerAddr, request.DirectoryRecordToken)
+	if err != nil {
+		return nil, errcode.ErrNotFound.Wrap(err)
+	}
+
+	client, err := svc.getDirectoryServiceClient(ctx, request.ServerAddr)
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	_, err = client.Unregister(ctx, &directorytypes.Unregister_Request{
+		DirectoryIdentifier:  record.Identifier,
+		DirectoryRecordToken: record.DirectoryRecordToken,
+		UnregisterToken:      record.DirectoryRecordUnregisterToken,
+	})
+	if err != nil {
+		// record is not found and has probably expired/been unregistered on another device
+		if !errcode.Is(err, errcode.ErrNotFound) {
+			return nil, errcode.ErrServicesDirectory.Wrap(err)
+		}
+	}
+
+	am, err := messengertypes.AppMessage_TypeAccountDirectoryServiceUnregistered.MarshalPayload(messengerutil.TimestampMs(time.Now()), "", &messengertypes.AppMessage_AccountDirectoryServiceUnregistered{
+		DirectoryRecordToken: record.DirectoryRecordToken,
+	})
+	if err != nil {
+		return nil, errcode.ErrSerialization.Wrap(err)
+	}
+
+	_, err = svc.protocolClient.AppMetadataSend(ctx, &protocoltypes.AppMetadataSend_Request{GroupPK: svc.accountGroup, Payload: am})
+	if err != nil {
+		return nil, errcode.ErrProtocolSend.Wrap(err)
+	}
+
+	return &messengertypes.DirectoryServiceUnregister_Reply{}, nil
+}
+
+func (svc *service) DirectoryServiceQuery(request *messengertypes.DirectoryServiceQuery_Request, server messengertypes.MessengerService_DirectoryServiceQueryServer) error {
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	client, err := svc.getDirectoryServiceClient(ctx, request.ServerAddr)
+	if err != nil {
+		return errcode.ErrInternal.Wrap(err)
+	}
+
+	results, err := client.Query(ctx, &directorytypes.Query_Request{
+		DirectoryIdentifiers: request.Identifiers,
+	})
+	if err != nil {
+		return errcode.ErrServicesDirectory.Wrap(err)
+	}
+
+	for {
+		result, err := results.Recv()
+		if err != nil {
+			if err == io.EOF {
+				break
+			}
+
+			return err
+		}
+
+		if err := server.Send(&messengertypes.DirectoryServiceQuery_Reply{
+			DirectoryIdentifier: result.DirectoryIdentifier,
+			ExpiresAt:           result.ExpiresAt,
+			AccountURI:          result.AccountURI,
+			VerifiedCredential:  result.VerifiedCredential,
+		}); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
