@@ -21,19 +21,19 @@ import (
 	"moul.io/zapgorm2"
 	"moul.io/zapring"
 
-	"berty.tech/berty/v2/go/internal/lifecycle"
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerpayloads"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/internal/notification"
-	"berty.tech/berty/v2/go/pkg/bertyprotocol"
-	"berty.tech/berty/v2/go/pkg/bertypush"
 	"berty.tech/berty/v2/go/pkg/bertyversion"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	mt "berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
-	"berty.tech/berty/v2/go/pkg/tyber"
+	"berty.tech/weshnet"
+	weshnet_errcode "berty.tech/weshnet/pkg/errcode"
+	"berty.tech/weshnet/pkg/lifecycle"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
 )
 
 type Service interface {
@@ -59,7 +59,6 @@ type service struct {
 	lcmanager             *lifecycle.Manager
 	eventHandler          *messengerpayloads.EventHandler
 	ring                  *zapring.Core
-	pushReceiver          bertypush.MessengerPushReceiver
 	tyberCleanup          func()
 	logFilePath           string
 	cancelGroupStatus     map[string] /*groupPK */ context.CancelFunc
@@ -71,6 +70,11 @@ type service struct {
 	subsMutex             *sync.Mutex
 	groupsToSubTo         map[string]struct{}
 	accountGroup          []byte
+	grpcInsecure          bool
+	dd                    debugCommand
+	// pushReceiver          bertypush.MessengerPushReceiver // FIXME(push): unavailable
+
+	mt.UnimplementedMessengerServiceServer
 }
 
 type Opts struct {
@@ -82,6 +86,7 @@ type Opts struct {
 	StateBackup         *mt.LocalDatabaseState
 	PlatformPushToken   *protocoltypes.PushServiceReceiver
 	Ring                *zapring.Core
+	GRPCInsecureMode    bool
 
 	// LogFilePath defines the location of the current session's log file.
 	//
@@ -126,8 +131,8 @@ func (opts *Opts) applyDefaults() (func(), error) {
 	return cleanup, nil
 }
 
-func databaseStateRestoreAccountHandler(statePointer *mt.LocalDatabaseState) bertyprotocol.RestoreAccountHandler {
-	return bertyprotocol.RestoreAccountHandler{
+func databaseStateRestoreAccountHandler(statePointer *mt.LocalDatabaseState) weshnet.RestoreAccountHandler {
+	return weshnet.RestoreAccountHandler{
 		Handler: func(header *tar.Header, reader *tar.Reader) (bool, error) {
 			if header.Name != exportLocalDBState {
 				return false, nil
@@ -155,8 +160,8 @@ func databaseStateRestoreAccountHandler(statePointer *mt.LocalDatabaseState) ber
 	}
 }
 
-func RestoreFromAccountExport(ctx context.Context, reader io.Reader, coreAPI ipfs_interface.CoreAPI, odb *bertyprotocol.BertyOrbitDB, localDBState *mt.LocalDatabaseState, logger *zap.Logger) error {
-	return bertyprotocol.RestoreAccountExport(ctx, reader, coreAPI, odb, logger, databaseStateRestoreAccountHandler(localDBState))
+func RestoreFromAccountExport(ctx context.Context, reader io.Reader, coreAPI ipfs_interface.CoreAPI, odb *weshnet.WeshOrbitDB, localDBState *mt.LocalDatabaseState, logger *zap.Logger) error {
+	return weshnet.RestoreAccountExport(ctx, reader, coreAPI, odb, logger, databaseStateRestoreAccountHandler(localDBState))
 }
 
 func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err error) {
@@ -191,7 +196,7 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 
 	ctx, cancel = context.WithCancel(context.Background())
 
-	icr, err := client.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+	icr, err := client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	cancel()
 	if err != nil {
 		return nil, errcode.TODO.Wrap(fmt.Errorf("error while getting instance configuration: %w", err))
@@ -229,10 +234,13 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 		subsMutex:             &sync.Mutex{},
 		groupsToSubTo:         make(map[string]struct{}),
 		accountGroup:          icr.GetAccountGroupPK(),
+		grpcInsecure:          opts.GRPCInsecureMode,
 	}
 
 	svc.eventHandler = messengerpayloads.NewEventHandler(ctx, db, &MetaFetcherFromProtocolClient{client: client}, newPostActionsService(&svc), opts.Logger, svc.dispatcher, false)
-	svc.pushReceiver = bertypush.NewPushReceiver(bertypush.NewPushHandlerViaProtocol(ctx, client), svc.eventHandler, svc.db, opts.Logger)
+
+	// @FIXME(push): temporary use noop push receiver
+	// svc.pushReceiver = bertypush.NewNoopPushReceiver()
 
 	// get or create account in DB
 	{
@@ -291,18 +299,19 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 	}})
 
 	if opts.PlatformPushToken != nil {
-		icr, err = client.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
+		icr, err = client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 		if err != nil {
 			return nil, err
 		}
 
-		if icr.DevicePushToken == nil || (icr.DevicePushToken.TokenType == opts.PlatformPushToken.TokenType && !bytes.Equal(icr.DevicePushToken.Token, opts.PlatformPushToken.Token)) {
-			if _, err := client.PushSetDeviceToken(ctx, &protocoltypes.PushSetDeviceToken_Request{
-				Receiver: opts.PlatformPushToken,
-			}); err != nil {
-				return nil, errcode.ErrInternal.Wrap(err)
-			}
-		}
+		// FIXME(push): PushSetDeviceToken not available anymore
+		// if icr.DevicePushToken == nil || (icr.DevicePushToken.TokenType == opts.PlatformPushToken.TokenType && !bytes.Equal(icr.DevicePushToken.Token, opts.PlatformPushToken.Token)) {
+		// if _, err := client.PushSetDeviceToken(ctx, &protocoltypes.PushSetDeviceToken_Request{
+		// 	Receiver: opts.PlatformPushToken,
+		// }); err != nil {
+		// 	return nil, errcode.ErrInternal.Wrap(err)
+		// }
+		// }
 	}
 
 	// Subscribe to account group metadata
@@ -473,12 +482,12 @@ func (svc *service) sharePushTokenForConversation(conversation *mt.Conversation)
 
 	if account.DevicePushToken == nil {
 		svc.logger.Warn("no push token known, won't share it")
-		return errcode.ErrPushUnknownDestination.Wrap(fmt.Errorf("no push token known, won't share it"))
+		return weshnet_errcode.ErrPushUnknownDestination.Wrap(fmt.Errorf("no push token known, won't share it"))
 	}
 
 	if account.DevicePushServer == nil {
 		svc.logger.Warn("no push server known, won't share push token")
-		return errcode.ErrPushUnknownProvider.Wrap(fmt.Errorf("no push server known, won't share push token"))
+		return weshnet_errcode.ErrPushUnknownProvider.Wrap(fmt.Errorf("no push server known, won't share push token"))
 	}
 
 	pushServer := &protocoltypes.PushServer{}
@@ -514,19 +523,20 @@ func (svc *service) sharePushTokenForConversationInternal(conversation *mt.Conve
 
 	tokenIdentifier := makeSharedPushIdentifier(pushServer, pushToken)
 
-	pubKey, err := messengerutil.B64DecodeBytes(conversation.PublicKey)
-	if err != nil {
-		return errcode.ErrSerialization.Wrap(err)
-	}
+	// pubKey, err := messengerutil.B64DecodeBytes(conversation.PublicKey)
+	// if err != nil {
+	// 	return errcode.ErrSerialization.Wrap(err)
+	// }
 
 	if conversation.SharedPushTokenIdentifier != tokenIdentifier {
-		if _, err := svc.protocolClient.PushShareToken(svc.ctx, &protocoltypes.PushShareToken_Request{
-			GroupPK:  pubKey,
-			Server:   pushServer,
-			Receiver: pushToken,
-		}); err != nil {
-			return err
-		}
+		// FIXME(push): push share token not available anymore
+		// if _, err := svc.protocolClient.PushShareToken(svc.ctx, &protocoltypes.PushShareToken_Request{
+		// 	GroupPK:  pubKey,
+		// 	Server:   pushServer,
+		// 	Receiver: pushToken,
+		// }); err != nil {
+		// 	return err
+		// }
 
 		if _, err := svc.db.UpdateConversation(mt.Conversation{PublicKey: conversation.PublicKey, SharedPushTokenIdentifier: tokenIdentifier}); err != nil {
 			return errcode.ErrDBWrite.Wrap(err)
