@@ -13,10 +13,10 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"berty.tech/berty/v2/go/internal/testutil"
 	"berty.tech/berty/v2/go/pkg/bertymessenger"
 	bertymessengertesting "berty.tech/berty/v2/go/pkg/bertymessenger/testing"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
+	"berty.tech/weshnet/pkg/testutil"
 )
 
 func TestPeersCreateJoinConversationNonMocked(t *testing.T) {
@@ -28,8 +28,7 @@ func TestPeersCreateJoinConversationNonMocked(t *testing.T) {
 	logger, cleanup := testutil.Logger(t)
 	defer cleanup()
 	accountsAmount := 3
-	clients, _, cleanup := bertymessengertesting.NonMockedTestingInfra(t, accountsAmount)
-	defer cleanup()
+	clients, _ := bertymessengertesting.NonMockedTestingInfra(t, accountsAmount)
 
 	// create nodes
 	var creator *bertymessenger.TestingAccount
