@@ -9,13 +9,14 @@ import (
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
 
-	"berty.tech/berty/v2/go/internal/lifecycle"
-	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	mt "berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/protocoltypes"
-	"berty.tech/berty/v2/go/pkg/tyber"
+	weshnet_errcode "berty.tech/weshnet/pkg/errcode"
+	"berty.tech/weshnet/pkg/lifecycle"
+	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/pkg/tyber"
 )
 
 func (svc *service) manageSubscriptions() {
@@ -234,13 +235,13 @@ func (svc *service) subscribeToMessages(ctx, tyberCtx context.Context, gpkb []by
 				eventHandler = eventHandler.WithContext(tyber.ContextWithConstantTraceID(svc.eventHandler.Ctx(), "msgrcvd-"+cid.String()))
 			}
 
-			svc.handlerMutex.Lock()
-			if err := eventHandler.HandleAppMessage(messengerutil.B64EncodeBytes(gpkb), gme, &am); err != nil {
-				_ = tyber.LogFatalError(eventHandler.Ctx(), eventHandler.Logger(), "Failed to handle AppMessage", err)
-			} else {
-				eventHandler.Logger().Debug("AppMessage handler succeeded", tyber.FormatStepLogFields(eventHandler.Ctx(), []tyber.Detail{}, tyber.EndTrace)...)
-			}
-			svc.handlerMutex.Unlock()
+			go func() {
+				if err := eventHandler.HandleAppMessage(messengerutil.B64EncodeBytes(gpkb), gme, &am); err != nil {
+					_ = tyber.LogFatalError(eventHandler.Ctx(), eventHandler.Logger(), "Failed to handle AppMessage", err)
+				} else {
+					eventHandler.Logger().Debug("AppMessage handler succeeded", tyber.FormatStepLogFields(eventHandler.Ctx(), []tyber.Detail{}, tyber.EndTrace)...)
+				}
+			}()
 		}
 	}()
 	return nil
@@ -256,7 +257,7 @@ func (svc *service) subscribeToGroup(ctx, tyberCtx context.Context, gpkb []byte)
 	if _, err := svc.protocolClient.ActivateGroup(ctx, &protocoltypes.ActivateGroup_Request{
 		GroupPK: gpkb,
 	}); err != nil {
-		return errcode.ErrGroupActivate.Wrap(err)
+		return weshnet_errcode.ErrGroupActivate.Wrap(err)
 	}
 
 	if err := svc.subscribeToMetadata(ctx, tyberCtx, gpkb); err != nil {
