@@ -9,6 +9,8 @@ import (
 	"encoding/json"
 	"fmt"
 	"net/http"
+	"net/url"
+	"testing"
 	"time"
 
 	ariesDocLD "github.com/hyperledger/aries-framework-go/pkg/doc/ld"
@@ -18,12 +20,13 @@ import (
 	"golang.org/x/crypto/curve25519"
 	"golang.org/x/crypto/nacl/box"
 
-	"berty.tech/berty/v2/go/internal/cryptoutil"
 	"berty.tech/berty/v2/go/pkg/bertylinks"
 	"berty.tech/berty/v2/go/pkg/bertyvcissuer/templates"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/berty/v2/go/pkg/verifiablecredstypes"
+	weshnet_vc "berty.tech/weshnet/pkg/bertyvcissuer"
+	"berty.tech/weshnet/pkg/cryptoutil"
+	"berty.tech/weshnet/pkg/verifiablecredstypes"
 )
 
 const cryptoChallengeTimeout = 10 * time.Minute
@@ -94,7 +97,7 @@ func New(config *Config) (*VCIssuer, error) {
 			return nil, err
 		}
 
-		config.IssuerID = fmt.Sprintf("did:key:%s", mbKey)
+		config.IssuerID = fmt.Sprintf("did:key:%s#%s", mbKey, mbKey)
 	}
 
 	if config.Flow == nil {
@@ -139,9 +142,9 @@ func New(config *Config) (*VCIssuer, error) {
 func (i *VCIssuer) serveMux() *http.ServeMux {
 	mux := http.NewServeMux()
 
-	mux.HandleFunc(PathChallenge, i.challenge)
-	mux.HandleFunc(PathAuthenticate, i.authenticate)
-	mux.HandleFunc(PathProof, i.proof)
+	mux.HandleFunc(weshnet_vc.PathChallenge, i.challenge)
+	mux.HandleFunc(weshnet_vc.PathAuthenticate, i.authenticate)
+	mux.HandleFunc(weshnet_vc.PathProof, i.proof)
 
 	return mux
 }
@@ -164,20 +167,20 @@ func (i *VCIssuer) error(err error, w http.ResponseWriter, _ *http.Request) {
 }
 
 func (i *VCIssuer) challenge(w http.ResponseWriter, r *http.Request) {
-	bertyID := r.URL.Query().Get(ParamBertyID)
+	bertyID := r.URL.Query().Get(weshnet_vc.ParamBertyID)
 	nonce, err := cryptoutil.GenerateNonce()
 	if err != nil {
 		i.error(err, w, r)
 		return
 	}
 
-	state := r.URL.Query().Get(ParamState)
+	state := r.URL.Query().Get(weshnet_vc.ParamState)
 	if len(state) == 0 {
 		i.error(ErrFlowStateMissing, w, r)
 		return
 	}
 
-	redirectURI := r.URL.Query().Get(ParamRedirectURI)
+	redirectURI := r.URL.Query().Get(weshnet_vc.ParamRedirectURI)
 	if len(redirectURI) == 0 {
 		i.error(ErrFlowRedirectURIMissing, w, r)
 		return
@@ -234,53 +237,63 @@ func (i *VCIssuer) computeChallenge(timestamp time.Time, bertyIDLink string, non
 	return boxed, parsedLink, nil
 }
 
-func (i *VCIssuer) checkAuthenticateChallenge(w http.ResponseWriter, r *http.Request) {
-	challengeStr := r.URL.Query().Get(ParamChallenge)
-	challengeSigStr := r.URL.Query().Get(ParamChallengeSig)
-
+func (i *VCIssuer) checkAndGetChallenge(challengeStr string) (*verifiablecredstypes.StateChallenge, []byte, error) {
 	challengeBytes, err := base64.URLEncoding.DecodeString(challengeStr)
 	if err != nil {
-		i.error(err, w, r)
-		return
+		return nil, nil, err
 	}
 
 	decryptedChallengeBytes, ok := box.OpenAnonymous(nil, challengeBytes, i.issuerPub, i.issuerPriv)
 	if !ok {
-		i.error(ErrChallengeAuthenticity, w, r)
-		return
+		return nil, nil, ErrChallengeAuthenticity
 	}
 
 	challenge := &verifiablecredstypes.StateChallenge{}
 	if err := challenge.Unmarshal(decryptedChallengeBytes); err != nil {
-		i.error(ErrChallengeVerify, w, r)
-		return
+		return nil, nil, ErrChallengeVerify
 	}
 
 	issuedAt := time.Now()
 	if err := issuedAt.UnmarshalBinary(challenge.Timestamp); err != nil {
-		i.error(ErrChallengeVerify, w, r)
-		return
+		return nil, nil, ErrChallengeVerify
 	}
 
 	if issuedAt.Before(time.Now().Add(-cryptoChallengeTimeout)) {
-		i.error(ErrChallengeExpired, w, r)
-		return
+		return nil, nil, ErrChallengeExpired
 	}
 
+	return challenge, challengeBytes, nil
+}
+
+func (i *VCIssuer) checkChallengeIssuerSig(challenge *verifiablecredstypes.StateChallenge, challengeBytes []byte, challengeSigStr string) error {
 	challengeClientSig, err := base64.URLEncoding.DecodeString(challengeSigStr)
 	if err != nil {
-		i.error(err, w, r)
-		return
+		return err
 	}
 
 	link, err := bertylinks.UnmarshalLink(challenge.BertyLink, nil)
+	if err != nil {
+		return err
+	}
+
+	if ok := ed25519.Verify(link.BertyID.AccountPK, challengeBytes, challengeClientSig); !ok {
+		return ErrChallengeFailed
+	}
+
+	return nil
+}
+
+func (i *VCIssuer) checkAuthenticateChallenge(w http.ResponseWriter, r *http.Request) {
+	challengeStr := r.URL.Query().Get(weshnet_vc.ParamChallenge)
+	challenge, challengeBytes, err := i.checkAndGetChallenge(challengeStr)
 	if err != nil {
 		i.error(err, w, r)
 		return
 	}
 
-	if ok := ed25519.Verify(link.BertyID.AccountPK, challengeBytes, challengeClientSig); !ok {
-		i.error(ErrChallengeFailed, w, r)
+	challengeSigStr := r.URL.Query().Get(weshnet_vc.ParamChallengeSig)
+	if err := i.checkChallengeIssuerSig(challenge, challengeBytes, challengeSigStr); err != nil {
+		i.error(err, w, r)
 		return
 	}
 
@@ -347,7 +360,7 @@ func (i *VCIssuer) openVerifiableContext(stateBase64 string) (*verifiablecredsty
 }
 
 func (i *VCIssuer) authenticate(w http.ResponseWriter, r *http.Request) {
-	stateStr := r.URL.Query().Get(ParamContext)
+	stateStr := r.URL.Query().Get(weshnet_vc.ParamContext)
 	if len(stateStr) == 0 {
 		i.checkAuthenticateChallenge(w, r)
 		return
@@ -366,7 +379,7 @@ func (i *VCIssuer) authenticate(w http.ResponseWriter, r *http.Request) {
 			i.error(err, w, r)
 			return
 		}
-		state.Identifier = r.PostForm.Get(ParamIdentifier)
+		state.Identifier = r.PostForm.Get(weshnet_vc.ParamIdentifier)
 		if len(state.Identifier) == 0 {
 			r.Method = http.MethodGet
 			i.authenticate(w, r)
@@ -422,7 +435,7 @@ func (i *VCIssuer) authenticate(w http.ResponseWriter, r *http.Request) {
 }
 
 func (i *VCIssuer) proof(w http.ResponseWriter, r *http.Request) {
-	stateStr := r.URL.Query().Get(ParamContext)
+	stateStr := r.URL.Query().Get(weshnet_vc.ParamContext)
 	if len(stateStr) == 0 {
 		i.error(fmt.Errorf("missing context"), w, r)
 		return
@@ -447,7 +460,7 @@ func (i *VCIssuer) proof(w http.ResponseWriter, r *http.Request) {
 			return
 		}
 
-		code := r.PostForm.Get(ParamCode)
+		code := r.PostForm.Get(weshnet_vc.ParamCode)
 
 		if code == state.Code {
 			signedProof, err := i.CreateSignedProof(state.BertyLink, state.Identifier)
@@ -483,3 +496,55 @@ func (i *VCIssuer) proof(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 }
+
+func (i *VCIssuer) TestHelperIssueTokenCallbackURI(t *testing.T, initURL string, identifier string) string {
+	t.Helper()
+
+	timestamp, err := time.Now().MarshalBinary()
+	if err != nil {
+		t.Error(err)
+		return ""
+	}
+
+	parsedInitURL, err := url.Parse(initURL)
+	if err != nil {
+		t.Error(err)
+		return ""
+	}
+
+	challengeStr := parsedInitURL.Query().Get(weshnet_vc.ParamChallenge)
+	challenge, challengeBytes, err := i.checkAndGetChallenge(challengeStr)
+	if err != nil {
+		t.Error(err)
+		return ""
+	}
+
+	challengeSigStr := parsedInitURL.Query().Get(weshnet_vc.ParamChallengeSig)
+	if err := i.checkChallengeIssuerSig(challenge, challengeBytes, challengeSigStr); err != nil {
+		t.Error(err)
+		return ""
+	}
+
+	stateCode := &verifiablecredstypes.StateCode{
+		Timestamp:   timestamp,
+		BertyLink:   challenge.BertyLink,
+		RedirectURI: challenge.RedirectURI,
+		State:       challenge.State,
+	}
+
+	signedProof, err := i.CreateSignedProof(challenge.BertyLink, identifier)
+	if err != nil {
+		t.Error(err)
+		return ""
+	}
+
+	return makeRedirectSuccessURI(stateCode.RedirectURI, stateCode.State, signedProof)
+}
+
+func (i *VCIssuer) GetIssuerID() string {
+	return i.issuerID
+}
+
+func (i *VCIssuer) GetServerRootURL() string {
+	return i.serverRootURL
+}
