@@ -144,10 +144,14 @@ const NameAvatar: React.FC<{
 			]}
 		>
 			<UnifiedText
+				adjustsFontSizeToFit
 				style={{
+					textAlign: 'center',
 					color: colors['reverted-main-text'],
 					fontSize: size * 0.5,
 					includeFontPadding: false,
+					// totally arbitrary, because by default the text is not centered, even if i follow some guides, don't know why
+					paddingBottom: size / 20,
 				}}
 			>
 				{char}
