@@ -5,8 +5,7 @@ import { ButtonDefProps, IconNameProps } from '../interfaces'
 import { TertiaryButtonPriv } from './TertiaryButton.priv'
 import { TertiaryTextPriv } from './TertiaryText.priv'
 
-// eslint-disable-next-line @typescript-eslint/no-unused-vars
-const TertiaryButtonIconRight: React.FC<ButtonDefProps & IconNameProps> = props => {
+export const TertiaryButtonIconRight: React.FC<ButtonDefProps & IconNameProps> = props => {
 	return (
 		<TertiaryButtonPriv {...props}>
 			<TertiaryTextPriv disabled={!!props.disabled}>{props.children}</TertiaryTextPriv>
