@@ -7,3 +7,6 @@ export { BootstrapDropdown } from './network/bootstrap/BootstrapDropdown'
 export { BootstrapAltDropdown } from './network/bootstrap/BootstrapAltDropdown'
 export { RendezvousDropdown } from './network/rendezvous/RendezvousDropdown'
 export { RendezvousAltDropdown } from './network/rendezvous/RendezvousAltDropdown'
+export { LinkedIdentityDropdown } from './linkedidentity/LinkedIdentityDropdown'
+export { DebugServerAddr } from './debugserveraddr/DebugServerAddr'
+export { DebugServersAddrCapabilities } from './debugserversaddrcapabilities/DebugServersAddrCapabilities'
