@@ -9,10 +9,7 @@ export const RendezvousAltDropdown: React.FC<NetworkProps> = props => {
 	const { t } = useTranslation()
 
 	return (
-		<NetworkAltDropdownPriv
-			placeholder={t('settings.network.rdvp-button')}
-			accessibilityLabel={props.accessibilityLabel}
-		>
+		<NetworkAltDropdownPriv placeholder={t('settings.network.rdvp-button')} testID={props.testID}>
 			<RendezvousItemsPriv />
 		</NetworkAltDropdownPriv>
 	)
