@@ -1,10 +1,10 @@
-import beapi from '@berty-tech/api'
+import beapi from '@berty/api'
 
 import Basic from './Basic'
 import ContactRequestReceived from './ContactRequestReceived'
 import ContactRequestSent from './ContactRequestSent'
-import MessageReceived from './MessageReceived'
 import GroupInvitation from './GroupInvitation'
+import MessageReceived from './MessageReceived'
 
 const T = beapi.messenger.StreamEvent.Notified.Type
 
@@ -20,5 +20,3 @@ const notifications = {
 export default notifications
 
 export { Basic as DefaultNotification }
-
-export type NotificationKey = keyof typeof notifications
