@@ -43,8 +43,8 @@ export const Section: React.FC<{}> = ({ children }) => {
 export const ButtonSettingV2: React.FC<{
 	text: string
 	icon?: string | React.ReactNode
-	onPress?: (...args: any) => void
-	accessibilityLabel?: string
+	onPress?: () => void
+	testID?: string
 	toggle?: {
 		enable: boolean
 		value?: boolean
@@ -65,7 +65,7 @@ export const ButtonSettingV2: React.FC<{
 	pack,
 	disabled = false,
 	last = false,
-	accessibilityLabel,
+	testID,
 }) => {
 	const { padding, margin, opacity } = useStyles()
 	const { scaleSize } = useAppDimensions()
@@ -116,7 +116,7 @@ export const ButtonSettingV2: React.FC<{
 			<TouchableOpacity
 				onPress={!disabled ? onPress : () => {}}
 				activeOpacity={disabled ? disabledOpacity : 0.2}
-				accessibilityLabel={accessibilityLabel}
+				testID={testID}
 				style={[
 					padding.vertical.medium,
 					padding.horizontal.medium,
@@ -193,7 +193,7 @@ type SettingButtonProps = {
 	// action
 	previewValue?: string
 	previewValueColor?: string
-	onPress?: (...args: any) => void
+	onPress?: () => void
 	disabled?: boolean
 	rightComponent?: ReactNode
 }
