@@ -2,7 +2,7 @@ import React, { FC } from 'react'
 import { TextInputProps, TextInput as RNTextInput, View, ViewProps } from 'react-native'
 
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store'
+import { useThemeColor } from '@berty/hooks'
 
 import { UnifiedText } from './UnifiedText'
 
