@@ -13,8 +13,8 @@ export type ServiceClientType<S> = S extends beapi.protocol.ProtocolService
 	: never
 
 export interface WelshProtocolServiceClient {
-	instanceExportData: ResponseStreamType<beapi.protocol.ProtocolService['instanceExportData']>
-	instanceGetConfiguration: UnaryType<beapi.protocol.ProtocolService['instanceGetConfiguration']>
+	serviceExportData: ResponseStreamType<beapi.protocol.ProtocolService['serviceExportData']>
+	serviceGetConfiguration: UnaryType<beapi.protocol.ProtocolService['serviceGetConfiguration']>
 	contactRequestReference: UnaryType<beapi.protocol.ProtocolService['contactRequestReference']>
 	contactRequestDisable: UnaryType<beapi.protocol.ProtocolService['contactRequestDisable']>
 	contactRequestEnable: UnaryType<beapi.protocol.ProtocolService['contactRequestEnable']>
@@ -56,6 +56,15 @@ export interface WelshProtocolServiceClient {
 	systemInfo: UnaryType<beapi.protocol.ProtocolService['systemInfo']>
 	authServiceInitFlow: UnaryType<beapi.protocol.ProtocolService['authServiceInitFlow']>
 	authServiceCompleteFlow: UnaryType<beapi.protocol.ProtocolService['authServiceCompleteFlow']>
+	credentialVerificationServiceInitFlow: UnaryType<
+		beapi.protocol.ProtocolService['credentialVerificationServiceInitFlow']
+	>
+	credentialVerificationServiceCompleteFlow: UnaryType<
+		beapi.protocol.ProtocolService['credentialVerificationServiceCompleteFlow']
+	>
+	verifiedCredentialsList: ResponseStreamType<
+		beapi.protocol.ProtocolService['verifiedCredentialsList']
+	>
 	servicesTokenList: ResponseStreamType<beapi.protocol.ProtocolService['servicesTokenList']>
 	replicationServiceRegisterGroup: UnaryType<
 		beapi.protocol.ProtocolService['replicationServiceRegisterGroup']
@@ -144,6 +153,13 @@ export interface WelshMessengerServiceClient {
 		beapi.messenger.MessengerService['pushTokenSharedForConversation']
 	>
 	pushReceive: UnaryType<beapi.messenger.MessengerService['pushReceive']>
+	directoryServiceRegister: UnaryType<beapi.messenger.MessengerService['directoryServiceRegister']>
+	directoryServiceUnregister: UnaryType<
+		beapi.messenger.MessengerService['directoryServiceUnregister']
+	>
+	directoryServiceQuery: ResponseStreamType<
+		beapi.messenger.MessengerService['directoryServiceQuery']
+	>
 }
 
 export interface WelshBridgeServiceClient {
