@@ -56,44 +56,53 @@ export const useAccountServices = (): Array<beapi.messenger.IServiceToken> => {
 /**
  * hooks for differents actions after closing account
  */
-const resetToClosing = (reset: NavigationProp<ScreensParams>['reset'], callback: () => void) => {
+const resetToClosing = async (
+	reset: NavigationProp<ScreensParams>['reset'],
+	callback: () => void,
+) => {
 	reset({ routes: [{ name: 'Account.Closing', params: { callback } }] })
 }
 
+export const closeBridgeAndNavigateToOnboarding = async (
+	reset: NavigationProp<ScreensParams>['reset'],
+	selectedAccount: string | null,
+) => {
+	await GoBridge.closeBridge()
+	reset({
+		routes: [
+			{
+				name: 'Account.SelectNode',
+				params: {
+					init: true,
+					action: async (external: boolean, address: string, port: string) => {
+						const res = await initBridge(external, address, port)
+						if (!res) {
+							Alert.alert('bridge: init failed')
+							return false
+						}
+
+						reset({
+							index: 0,
+							routes: [
+								{
+									name: 'Account.GoToLogInOrCreate',
+									params: { isCreate: false, selectedAccount },
+								},
+							],
+						})
+						return true
+					},
+				},
+			},
+		],
+	})
+}
+
 export const useSwitchAccountAfterClosing = () => {
 	const { reset } = useNavigation()
 	return useCallback(
 		(selectedAccount: string | null) =>
-			resetToClosing(reset, () =>
-				reset({
-					routes: [
-						{
-							name: 'Account.SelectNode',
-							params: {
-								init: true,
-								action: async (external: boolean, address: string, port: string) => {
-									const res = await initBridge(external, address, port)
-									if (!res) {
-										Alert.alert('bridge: init failed')
-										return false
-									}
-
-									reset({
-										index: 0,
-										routes: [
-											{
-												name: 'Account.GoToLogInOrCreate',
-												params: { isCreate: false, selectedAccount },
-											},
-										],
-									})
-									return true
-								},
-							},
-						},
-					],
-				}),
-			),
+			resetToClosing(reset, async () => closeBridgeAndNavigateToOnboarding(reset, selectedAccount)),
 		[reset],
 	)
 }
@@ -107,8 +116,9 @@ export const useRestartAfterClosing = () => {
 export const useOnBoardingAfterClosing = () => {
 	const { reset } = useNavigation()
 	return useCallback(
-		() =>
-			resetToClosing(reset, () =>
+		async () =>
+			await resetToClosing(reset, async () => {
+				await GoBridge.closeBridge()
 				reset({
 					routes: [
 						{
@@ -131,8 +141,8 @@ export const useOnBoardingAfterClosing = () => {
 							},
 						},
 					],
-				}),
-			),
+				})
+			}),
 		[reset],
 	)
 }
@@ -140,8 +150,9 @@ export const useOnBoardingAfterClosing = () => {
 export const useImportingAccountAfterClosing = () => {
 	const { reset } = useNavigation()
 	return useCallback(
-		(filePath: string) =>
-			resetToClosing(reset, () =>
+		async (filePath: string) =>
+			await resetToClosing(reset, async () => {
+				await GoBridge.closeBridge()
 				reset({
 					routes: [
 						{
@@ -161,8 +172,8 @@ export const useImportingAccountAfterClosing = () => {
 							},
 						},
 					],
-				}),
-			),
+				})
+			}),
 		[reset],
 	)
 }
