@@ -208,12 +208,28 @@ export type MessengerMethodsHooks = {
 		called: boolean
 		loading: boolean
 	}
+	useDirectoryServiceRegister: () => {
+		error: any
+		call: (req?: beapi.messenger.DirectoryServiceRegister.IRequest) => void
+		reply: beapi.messenger.DirectoryServiceRegister.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
+	}
+	useDirectoryServiceUnregister: () => {
+		error: any
+		call: (req?: beapi.messenger.DirectoryServiceUnregister.IRequest) => void
+		reply: beapi.messenger.DirectoryServiceUnregister.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
+	}
 }
 export type ProtocolMethodsHooks = {
-	useInstanceGetConfiguration: () => {
+	useServiceGetConfiguration: () => {
 		error: any
-		call: (req?: beapi.protocol.InstanceGetConfiguration.IRequest) => void
-		reply: beapi.protocol.InstanceGetConfiguration.IReply | null
+		call: (req?: beapi.protocol.ServiceGetConfiguration.IRequest) => void
+		reply: beapi.protocol.ServiceGetConfiguration.IReply | null
 		done: boolean
 		called: boolean
 		loading: boolean
@@ -426,6 +442,22 @@ export type ProtocolMethodsHooks = {
 		called: boolean
 		loading: boolean
 	}
+	useCredentialVerificationServiceInitFlow: () => {
+		error: any
+		call: (req?: beapi.protocol.CredentialVerificationServiceInitFlow.IRequest) => void
+		reply: beapi.protocol.CredentialVerificationServiceInitFlow.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
+	}
+	useCredentialVerificationServiceCompleteFlow: () => {
+		error: any
+		call: (req?: beapi.protocol.CredentialVerificationServiceCompleteFlow.IRequest) => void
+		reply: beapi.protocol.CredentialVerificationServiceCompleteFlow.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
+	}
 	useReplicationServiceRegisterGroup: () => {
 		error: any
 		call: (req?: beapi.protocol.ReplicationServiceRegisterGroup.IRequest) => void
