@@ -5,6 +5,10 @@ class NoopGoBirdge implements GoBridgeInterface {
 		return Promise.reject()
 	}
 
+	initBridgeRemote() {
+		return Promise.reject()
+	}
+
 	closeBridge() {
 		return Promise.reject()
 	}
@@ -18,6 +22,10 @@ class NoopGoBirdge implements GoBridgeInterface {
 	invokeBridgeMethod() {
 		return Promise.reject()
 	}
+
+	connectService() {
+		return Promise.reject()
+	}
 }
 
 export const GoBridge: GoBridgeInterface = new NoopGoBirdge()
