@@ -518,6 +518,28 @@ export const Navigation: React.FC = React.memo(() => {
 					presentation: 'formSheet',
 				}}
 			/>
+			<NavigationStack.Screen
+				name='Settings.LinkedIdentities'
+				component={Components.Settings.LinkedIdentities}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.linked-identities.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name='Settings.DirectorySearch'
+				component={Components.Settings.DirectorySearch}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.directory-search.title'),
+					presentation: 'formSheet',
+				}}
+			/>
 			<NavigationStack.Screen
 				name='Settings.AboutBerty'
 				component={Components.Settings.AboutBerty}
