@@ -43,12 +43,24 @@ export const messengerActions = {
 		beapi.messenger.StreamEvent.INotified,
 		'messenger/Notified'
 	>('messenger/Notified'),
-	[beapi.messenger.StreamEvent.Type.TypeMediaUpdated]: createAction<
-		beapi.messenger.StreamEvent.IMediaUpdated,
-		'messenger/MediaUpdated'
-	>('messenger/MediaUpdated'),
 	[beapi.messenger.StreamEvent.Type.TypeConversationPartialLoad]: createAction<
 		beapi.messenger.StreamEvent.IConversationPartialLoad,
 		'messenger/ConversationPartialLoad'
 	>('messenger/ConversationPartialLoad'),
+	[beapi.messenger.StreamEvent.Type.TypePeerStatusConnected]: createAction<
+		beapi.messenger.StreamEvent.IPeerStatusConnected,
+		'messenger/PeerStatusConnected'
+	>('messenger/PeerStatusConnected'),
+	[beapi.messenger.StreamEvent.Type.TypePeerStatusReconnecting]: createAction<
+		beapi.messenger.StreamEvent.IPeerStatusReconnecting,
+		'messenger/PeerStatusReconnecting'
+	>('messenger/PeerStatusReconnecting'),
+	[beapi.messenger.StreamEvent.Type.TypePeerStatusDisconnected]: createAction<
+		beapi.messenger.StreamEvent.IPeerStatusDisconnected,
+		'messenger/PeerStatusDisconnected'
+	>('messenger/PeerStatusDisconnected'),
+	[beapi.messenger.StreamEvent.Type.TypePeerStatusGroupAssociated]: createAction<
+		beapi.messenger.StreamEvent.IPeerStatusGroupAssociated,
+		'messenger/PeerStatusGroupAssociated'
+	>('messenger/PeerStatusGroupAssociated'),
 }
