@@ -1,7 +1,6 @@
 import { Player } from '@react-native-community/audio-toolkit'
 import { Layout } from '@ui-kitten/components'
 import i18next from 'i18next'
-import Long from 'long'
 import React, { useCallback, useEffect, useRef, useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { Alert, Platform, ScrollView, StatusBar, Vibration, View } from 'react-native'
@@ -9,7 +8,14 @@ import { withInAppNotification } from 'react-native-in-app-notification'
 import { useSelector } from 'react-redux'
 
 import beapi from '@berty/api'
-import { AccountsDropdown, DividerItem, ItemSection, MenuItem } from '@berty/components'
+import {
+	AccountsDropdown,
+	DividerItem,
+	ItemSection,
+	MenuItem,
+	MenuItemWithIcon,
+	MenuToggleWithIcon,
+} from '@berty/components'
 import { DropDownPicker, Item } from '@berty/components/shared-components/DropDownPicker'
 import {
 	ButtonSetting,
@@ -18,9 +24,6 @@ import {
 	StringOptionInput,
 } from '@berty/components/shared-components/SettingsButtons'
 import { useStyles } from '@berty/contexts/styles'
-import { createServiceClient } from '@berty/grpc-bridge'
-import * as middleware from '@berty/grpc-bridge/middleware'
-import { bridge as rpcBridge } from '@berty/grpc-bridge/rpc'
 import {
 	useAllConversations,
 	useAllInteractions,
@@ -38,10 +41,15 @@ import {
 	useOnBoardingAfterClosing,
 	useImportingAccountAfterClosing,
 	useSwitchAccountAfterClosing,
+	useSyncNetworkConfigOnScreenRemoved,
 } from '@berty/hooks'
 import { languages } from '@berty/i18n/locale/languages'
 import { GoBridge } from '@berty/native-modules/GoBridge'
 import { ScreenFC, useNavigation } from '@berty/navigation'
+import {
+	selectEditedNetworkConfig,
+	setCurrentNetworkConfig,
+} from '@berty/redux/reducers/networkConfig.reducer'
 import {
 	PersistentOptionsKeys,
 	selectPersistentOptions,
@@ -117,58 +125,6 @@ const HeaderDevTools: React.FC<{}> = () => {
 	)
 }
 
-const NativeCallButton: React.FC = () => {
-	// create middleware(s) if needed
-	const messengerMiddlewares = middleware.chain(
-		__DEV__ ? middleware.logger.create('MESSENGER') : null,
-	)
-	const colors = useThemeColor()
-
-	const messengerClient = createServiceClient(
-		beapi.messenger.MessengerService,
-		rpcBridge,
-		messengerMiddlewares,
-	)
-	const { t } = useTranslation()
-	let i = 0
-	return (
-		<ButtonSetting
-			name={t('settings.devtools.native-bridge-button')}
-			icon='activity-outline'
-			iconSize={30}
-			iconColor={colors['secondary-text']}
-			onPress={() => {
-				const n = i
-				++i
-				console.info(`start of the EchoTest stream #${n}`)
-				messengerClient
-					.echoTest({
-						echo: `hello number #${n}`,
-						delay: Long.fromNumber(1000),
-					})
-					.then(stream => {
-						stream.onMessage(res => {
-							if (res) {
-								Vibration.vibrate(500)
-							}
-						})
-
-						setTimeout(stream.stop, 10000)
-						return stream.start()
-					})
-					.catch(err => {
-						if (err?.EOF) {
-							console.info(`end of the EchoTest stream #${n}`)
-						} else if (err) {
-							console.warn(err)
-						}
-					})
-				++i
-			}}
-		/>
-	)
-}
-
 const DiscordShareButton: React.FC = () => {
 	const { navigate, goBack } = useNavigation()
 	const account = useAccount()
@@ -363,6 +319,7 @@ const BodyDevTools: React.FC<{}> = withInAppNotification(({ showNotification }:
 	const selectedAccount = useAppSelector(selectSelectedAccount)
 	const restartOnboarding = useOnBoardingAfterClosing()
 	const [forceMock, setForceMock] = useState<boolean>(false)
+	const networkConfig = useSelector(selectEditedNetworkConfig)
 
 	const addTyberHost = useCallback(
 		(host: string, addresses: string[]) => {
@@ -489,6 +446,45 @@ const BodyDevTools: React.FC<{}> = withInAppNotification(({ showNotification }:
 					</>
 				)}
 			</ItemSection>
+
+			<ItemSection>
+				<DividerItem />
+				<MenuItemWithIcon
+					iconName='pricetags-outline'
+					onPress={() => navigate('Settings.LinkedIdentities')}
+				>
+					{t('settings.home.linked-identities-button')}
+				</MenuItemWithIcon>
+				<MenuItemWithIcon
+					iconName='book-outline'
+					onPress={() => navigate('Settings.DirectorySearch')}
+				>
+					{t('settings.home.directory-search-button')}
+				</MenuItemWithIcon>
+			</ItemSection>
+
+			<ItemSection>
+				<MenuToggleWithIcon
+					iconName='unlock-outline'
+					onPress={() =>
+						dispatch(
+							setCurrentNetworkConfig({
+								...networkConfig,
+								allowUnsecureGrpcConnections:
+									networkConfig?.allowUnsecureGrpcConnections ===
+									beapi.account.NetworkConfig.Flag.Enabled
+										? beapi.account.NetworkConfig.Flag.Disabled
+										: beapi.account.NetworkConfig.Flag.Enabled,
+							}),
+						)
+					}
+					isToggleOn={
+						networkConfig?.allowUnsecureGrpcConnections === beapi.account.NetworkConfig.Flag.Enabled
+					}
+				>
+					{t('settings.devtools.allow-unsecure-grpc')}
+				</MenuToggleWithIcon>
+			</ItemSection>
 			<View style={[padding.horizontal.medium]}>
 				<ButtonSetting
 					name={t('settings.devtools.force-mock-button')}
@@ -646,7 +642,6 @@ const BodyDevTools: React.FC<{}> = withInAppNotification(({ showNotification }:
 					onPress={() => navigation.navigate('Settings.AddDevConversations')}
 				/>
 				<DiscordShareButton />
-				<NativeCallButton />
 				<DumpAccount />
 				<DumpContacts />
 				<DumpConversations />
@@ -664,7 +659,6 @@ const BodyDevTools: React.FC<{}> = withInAppNotification(({ showNotification }:
 					icon='hard-drive-outline'
 					iconSize={30}
 					iconColor={colors['alt-secondary-background-header']}
-					toggled
 					disabled
 				/>
 				<ButtonSetting
@@ -733,6 +727,7 @@ const BodyDevTools: React.FC<{}> = withInAppNotification(({ showNotification }:
 export const DevTools: ScreenFC<'Settings.DevTools'> = () => {
 	const colors = useThemeColor()
 	const { padding } = useStyles()
+	useSyncNetworkConfigOnScreenRemoved()
 
 	return (
 		<Layout style={{ backgroundColor: colors['main-background'], flex: 1 }}>
