@@ -21,3 +21,5 @@ export { SystemInfo } from './SystemInfo/SystemInfo'
 export { AddDevConversations } from './AddDevConversations/AddDevConversations'
 export { FakeData } from './FakeData/FakeData'
 export { Permissions } from './Permissions/Permissions'
+export { LinkedIdentities } from './LinkedIdentities/LinkedIdentities'
+export { DirectorySearch } from './DirectorySearch/DirectorySearch'
